;;;
;;; Copyright (c) 2003-2012 uim Project http://code.google.com/p/uim/
;;;
;;; All rights reserved.
;;;
;;; Redistribution and use in source and binary forms, with or without
;;; modification, are permitted provided that the following conditions
;;; are met:
;;; 1. Redistributions of source code must retain the above copyright
;;;    notice, this list of conditions and the following disclaimer.
;;; 2. Redistributions in binary form must reproduce the above copyright
;;;    notice, this list of conditions and the following disclaimer in the
;;;    documentation and/or other materials provided with the distribution.
;;; 3. Neither the name of authors nor the names of its contributors
;;;    may be used to endorse or promote products derived from this software
;;;    without specific prior written permission.
;;;
;;; THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS'' AND
;;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
;;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
;;; ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE
;;; FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
;;; DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
;;; OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
;;; HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
;;; LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
;;; OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
;;; SUCH DAMAGE.
;;;;

;;; tutcode.scmѥơ֥
;;; TUT-CodeQWERTYܡѡ
(define tutcode-rule
  '(
    ; tutcode-key-custom
    ;((("a" "l" "a"))(tutcode-bushu-start)) ;ַѴ
    ;((("a" "l" "j"))(tutcode-mazegaki-start)) ;ַ򤼽Ѵ
    ((("r" "k"))("" ""))
    ((("r" "i"))("" ""))
    ((("r" "u"))("" ""))
    ((("r" "h"))("" ""))
    ((("r" "j"))("" ""))
    ((("e" "k"))("" ""))
    ((("e" "i"))("" ""))
    ((("e" "u"))("" ""))
    ((("e" "h"))("" ""))
    ((("e" "j"))("" ""))
    ((("s" "k"))("" ""))
    ((("s" "i"))("" ""))
    ((("s" "u"))("" ""))
    ((("s" "h"))("" ""))
    ((("s" "j"))("" ""))
    ((("d" "k"))("" ""))
    ((("d" "i"))("" ""))
    ((("d" "u"))("" ""))
    ((("d" "h"))("" ""))
    ((("d" "j"))("" ""))
    ((("f" "k"))("" ""))
    ((("f" "i"))("" ""))
    ((("f" "u"))("" ""))
    ((("f" "h"))("" ""))
    ((("f" "j"))("" ""))
    ((("t" "k"))("" ""))
    ((("t" "i"))("" ""))
    ((("t" "u"))("" ""))
    ((("t" "h"))("" ""))
    ((("t" "j"))("" ""))
    ((("w" "k"))("" ""))
    ((("w" "i"))("" ""))
    ((("w" "u"))("" ""))
    ((("w" "h"))("" ""))
    ((("w" "j"))("" ""))
    ((("q" "k"))("" ""))
    ((("q" "u"))("" ""))
    ((("q" "j"))("" ""))
    ((("g" "k"))("" ""))
    ((("g" "i"))("" ""))
    ((("g" "u"))("" ""))
    ((("g" "h"))("" ""))
    ((("g" "j"))("" ""))
    ((("a" "k"))("" ""))
    ((("a" "i"))("" ""))
    ((("a" "h"))("" ""))
    ((("a" "j"))("" ""))
    ((("r" "l" "k"))("" ""))
    ((("r" "l" "i"))("" ""))
    ((("r" "l" "u"))("" ""))
    ((("r" "l" "r" "u"))(""))
    ((("r" "l" "h"))("" ""))
    ((("r" "l" "j"))("" ""))
    ((("e" "l" "k"))("" ""))
    ((("e" "l" "e" "k"))(""))
    ((("e" "l" "i"))("" ""))
    ((("e" "l" "u"))("" ""))
    ((("e" "l" "h"))("" ""))
    ((("e" "l" "e" "h"))(""))
    ((("e" "l" "j"))("" ""))
    ((("s" "l" "k"))("" ""))
    ((("s" "l" "i"))("" ""))
    ((("s" "l" "u"))("" ""))
    ((("s" "l" "h"))("" ""))
    ((("s" "l" "j"))("" ""))
    ((("d" "l" "k"))("" ""))
    ((("d" "l" "i"))("" ""))
    ((("d" "l" "u"))("" ""))
    ((("d" "l" "d" "u"))("" ""))
    ((("d" "l" "h"))("" ""))
    ((("d" "l" "j"))("" ""))
    ((("f" "l"))("" ""))
    ((("t" "l" "k"))("" ""))
    ((("t" "l" "i"))("" ""))
    ((("t" "l" "u"))("" ""))
    ((("t" "l" "h"))("" ""))
    ((("t" "l" "j"))("" ""))
    ((("t" "l" "t" "k"))("" ""))
    ((("t" "l" "t" "i"))("" ""))
    ((("t" "l" "t" "u"))("" ""))
    ((("t" "l" "t" "h"))("" ""))
    ((("t" "l" "t" "j"))("" ""))
    ((("q" "l" "k"))("" ""))
    ((("q" "l" "u"))("" ""))
    ((("q" "l" "j"))("" ""))
    ((("a" "l" "k"))("" ""))
    ((("q" " "))(""))
    ((("w" " "))(""))
    ((("e" " "))(""))
    ((("r" " "))(""))
    ((("t" " "))(""))
    ((("y" " "))(""))
    ((("u" " "))(""))
    ((("i" " "))(""))
    ((("o" " "))(""))
    ((("p" " "))(""))
    ((("a" " "))(""))
    ((("s" " "))(""))
    ((("d" " "))(""))
    ((("f" " "))(""))
    ((("g" " "))(""))
    ((("h" " "))(""))
    ((("j" " "))(""))
    ((("k" " "))(""))
    ((("l" " "))(""))
    (((";" " "))(""))
    ((("z" " "))(""))
    ((("x" " "))(""))
    ((("c" " "))(""))
    ((("v" " "))(""))
    ((("b" " "))(""))
    ((("n" " "))(""))
    ((("m" " "))(""))
    ((("," " "))(""))
    ((("." " "))(""))
    ((("/" " "))(""))
    ((("," ","))(""))
    ((("," "."))(""))
    ((("," "/"))(""))
    ((("," ";"))(""))
    ((("," "a"))(""))
    ((("," "b"))(""))
    ((("," "c"))(""))
    ((("," "d"))(""))
    ((("," "e"))(""))
    ((("," "f"))("ʸ"))
    ((("," "g"))("¼"))
    ((("," "i"))(""))
    ((("," "j"))(""))
    ((("," "k"))("ϩ"))
    ((("," "l"))(""))
    ((("," "o"))(""))
    ((("," "p"))(""))
    ((("," "q"))(""))
    ((("," "r"))(""))
    ((("," "s"))("ī"))
    ((("," "t"))(""))
    ((("," "u"))("ι"))
    ((("," "v"))(""))
    ((("," "w"))(""))
    ((("," "x"))(""))
    ((("," "z"))(""))
    ((("." ","))(""))
    ((("." "."))(""))
    ((("." "/"))(""))
    ((("." ";"))("¨"))
    ((("." "a"))("ɩ"))
    ((("." "b"))(""))
    ((("." "c"))(""))
    ((("." "d"))(""))
    ((("." "e"))(""))
    ((("." "f"))(""))
    ((("." "g"))(""))
    ((("." "i"))(""))
    ((("." "j"))(""))
    ((("." "k"))(""))
    ((("." "l"))(""))
    ((("." "o"))(""))
    ((("." "p"))(""))
    ((("." "q"))(""))
    ((("." "r"))(""))
    ((("." "s"))(""))
    ((("." "t"))(""))
    ((("." "u"))(""))
    ((("." "v"))(""))
    ((("." "w"))(""))
    ((("." "x"))(""))
    ((("." "z"))("ͻ"))
    ((("/" ","))(""))
    ((("/" "."))(""))
    ((("/" "/"))(""))
    ((("/" ";"))(""))
    ((("/" "a"))(""))
    ((("/" "b"))("Φ"))
    ((("/" "c"))(""))
    ((("/" "d"))(""))
    ((("/" "e"))(""))
    ((("/" "f"))(""))
    ((("/" "g"))(""))
    ((("/" "i"))("͹"))
    ((("/" "j"))(""))
    ((("/" "k"))("Ư"))
    ((("/" "l"))(""))
    ((("/" "o"))(""))
    ((("/" "p"))(""))
    ((("/" "q"))(""))
    ((("/" "r"))("˭"))
    ((("/" "s"))(""))
    ((("/" "t"))(""))
    ((("/" "u"))(""))
    ((("/" "v"))(""))
    ((("/" "w"))(""))
    ((("/" "x"))(""))
    ((("/" "z"))(""))
    (((";" ","))(""))
    (((";" "."))(""))
    (((";" "/"))(""))
    (((";" ";"))(""))
    (((";" "a"))(""))
    (((";" "b"))(""))
    (((";" "c"))(""))
    (((";" "d"))(""))
    (((";" "e"))(""))
    (((";" "f"))(""))
    (((";" "g"))(""))
    (((";" "i"))(""))
    (((";" "j"))(""))
    (((";" "k"))(""))
    (((";" "l"))("¦"))
    (((";" "o"))(""))
    (((";" "p"))(""))
    (((";" "q"))(""))
    (((";" "r"))(""))
    (((";" "s"))(""))
    (((";" "t"))(""))
    (((";" "u"))(""))
    (((";" "v"))(""))
    (((";" "w"))(""))
    (((";" "x"))(""))
    (((";" "z"))(""))
    ((("a" ","))(""))
    ((("a" "."))(""))
    ((("a" "/"))(""))
    ((("a" ";"))(""))
    ((("a" "a"))(""))
    ((("a" "c"))(""))
    ((("a" "d"))(""))
    ((("a" "e"))("ŷ"))
    ((("a" "f"))("ľ"))
    ((("a" "m"))(""))
    ((("a" "n"))(""))
    ((("a" "o"))(""))
    ((("a" "p"))("³"))
    ((("a" "q"))(""))
    ((("a" "r"))(""))
    ((("a" "s"))(""))
    ((("a" "u"))(""))
    ((("a" "w"))(""))
    ((("a" "x"))("²"))
    ((("a" "y"))(""))
    ((("a" "z"))(""))
    ((("b" ","))(""))
    ((("b" "."))("ĥ"))
    ((("b" "/"))(""))
    ((("b" ";"))(""))
    ((("b" "a"))("̤"))
    ((("b" "c"))(""))
    ((("b" "d"))(""))
    ((("b" "e"))("Ψ"))
    ((("b" "f"))(""))
    ((("b" "h"))("¿"))
    ((("b" "i"))(""))
    ((("b" "j"))(""))
    ((("b" "k"))(""))
    ((("b" "l"))(""))
    ((("b" "m"))(""))
    ((("b" "n"))(""))
    ((("b" "o"))(""))
    ((("b" "p"))(""))
    ((("b" "q"))(""))
    ((("b" "r"))(""))
    ((("b" "s"))(""))
    ((("b" "u"))(""))
    ((("b" "w"))(""))
    ((("b" "x"))(""))
    ((("b" "y"))(""))
    ((("b" "z"))(""))
    ((("c" ","))(""))
    ((("c" "."))(""))
    ((("c" "/"))(""))
    ((("c" ";"))(""))
    ((("c" "a"))(""))
    ((("c" "c"))(""))
    ((("c" "d"))(""))
    ((("c" "e"))(""))
    ((("c" "f"))(""))
    ((("c" "h"))(""))
    ((("c" "i"))(""))
    ((("c" "j"))(""))
    ((("c" "k"))(""))
    ((("c" "l"))(""))
    ((("c" "m"))("ή"))
    ((("c" "n"))(""))
    ((("c" "o"))(""))
    ((("c" "p"))(""))
    ((("c" "q"))(""))
    ((("c" "r"))(""))
    ((("c" "s"))(""))
    ((("c" "u"))("Ĵ"))
    ((("c" "w"))(""))
    ((("c" "x"))(""))
    ((("c" "y"))(""))
    ((("c" "z"))(""))
    ((("d" ","))(""))
    ((("d" "."))(""))
    ((("d" "/"))(""))
    ((("d" ";"))("Ĺ"))
    ((("d" "a"))(""))
    ((("d" "c"))(""))
    ((("d" "d"))(""))
    ((("d" "e"))(""))
    ((("d" "f"))(""))
    ((("d" "m"))(""))
    ((("d" "n"))(""))
    ((("d" "o"))(""))
    ((("d" "p"))(""))
    ((("d" "q"))(""))
    ((("d" "r"))("ʿ"))
    ((("d" "s"))("¾"))
    ((("d" "w"))("̵"))
    ((("d" "x"))("Ʋ"))
    ((("d" "y"))(""))
    ((("d" "z"))(""))
    ((("e" ","))(""))
    ((("e" "."))(""))
    ((("e" "/"))(""))
    ((("e" ";"))(""))
    ((("e" "a"))(""))
    ((("e" "c"))(""))
    ((("e" "d"))(""))
    ((("e" "e"))(""))
    ((("e" "f"))(""))
    ((("e" "m"))(""))
    ((("e" "n"))(""))
    ((("e" "o"))(""))
    ((("e" "p"))(""))
    ((("e" "q"))("ξ"))
    ((("e" "r"))(""))
    ((("e" "s"))(""))
    ((("e" "w"))(""))
    ((("e" "x"))(""))
    ((("e" "y"))(""))
    ((("e" "z"))(""))
    ((("f" ","))("Ź"))
    ((("f" "."))(""))
    ((("f" "/"))("˾"))
    ((("f" ";"))(""))
    ((("f" "a"))(""))
    ((("f" "c"))(""))
    ((("f" "d"))(""))
    ((("f" "e"))(""))
    ((("f" "f"))(""))
    ((("f" "m"))(""))
    ((("f" "n"))(""))
    ((("f" "o"))(""))
    ((("f" "p"))(""))
    ((("f" "q"))(""))
    ((("f" "r"))(""))
    ((("f" "s"))(""))
    ((("f" "w"))(""))
    ((("f" "x"))("ʼ"))
    ((("f" "y"))(""))
    ((("f" "z"))(""))
    ((("g" ","))(""))
    ((("g" "."))(""))
    ((("g" "/"))(""))
    ((("g" ";"))(""))
    ((("g" "a"))(""))
    ((("g" "c"))(""))
    ((("g" "d"))(""))
    ((("g" "e"))(""))
    ((("g" "f"))(""))
    ((("g" "l"))(""))
    ((("g" "m"))(""))
    ((("g" "n"))(""))
    ((("g" "o"))(""))
    ((("g" "p"))(""))
    ((("g" "q"))(""))
    ((("g" "r"))(""))
    ((("g" "s"))(""))
    ((("g" "w"))(""))
    ((("g" "x"))(""))
    ((("g" "y"))(""))
    ((("g" "z"))(""))
    ((("h" ","))(""))
    ((("h" "."))(""))
    ((("h" "/"))(""))
    ((("h" ";"))(""))
    ((("h" "a"))("ƣ"))
    ((("h" "b"))(""))
    ((("h" "c"))(""))
    ((("h" "d"))(""))
    ((("h" "e"))(""))
    ((("h" "f"))(""))
    ((("h" "g"))(""))
    ((("h" "i"))("Ϣ"))
    ((("h" "j"))(""))
    ((("h" "k"))(""))
    ((("h" "l"))(""))
    ((("h" "o"))("ͳ"))
    ((("h" "p"))(""))
    ((("h" "q"))(""))
    ((("h" "r"))(""))
    ((("h" "s"))(""))
    ((("h" "t"))("̾"))
    ((("h" "u"))(""))
    ((("h" "v"))(""))
    ((("h" "w"))("ư"))
    ((("h" "x"))(""))
    ((("h" "z"))(""))
    ((("i" ","))(""))
    ((("i" "."))("ʧ"))
    ((("i" "/"))(""))
    ((("i" ";"))(""))
    ((("i" "a"))(""))
    ((("i" "b"))(""))
    ((("i" "c"))(""))
    ((("i" "d"))(""))
    ((("i" "e"))(""))
    ((("i" "f"))(""))
    ((("i" "g"))("ʬ"))
    ((("i" "i"))(""))
    ((("i" "j"))(""))
    ((("i" "k"))(""))
    ((("i" "l"))(""))
    ((("i" "o"))(""))
    ((("i" "p"))(""))
    ((("i" "q"))(""))
    ((("i" "r"))(""))
    ((("i" "s"))(""))
    ((("i" "t"))(""))
    ((("i" "u"))(""))
    ((("i" "v"))(""))
    ((("i" "w"))("̳"))
    ((("i" "x"))(""))
    ((("i" "z"))(""))
    ((("j" ","))("ʹ"))
    ((("j" "."))(""))
    ((("j" "/"))(""))
    ((("j" ";"))(""))
    ((("j" "a"))(""))
    ((("j" "b"))(""))
    ((("j" "c"))("ë"))
    ((("j" "d"))(""))
    ((("j" "e"))(""))
    ((("j" "f"))("ǯ"))
    ((("j" "g"))(""))
    ((("j" "i"))(""))
    ((("j" "j"))(""))
    ((("j" "k"))(""))
    ((("j" "l"))("ʪ"))
    ((("j" "o"))(""))
    ((("j" "p"))(""))
    ((("j" "q"))(""))
    ((("j" "r"))(""))
    ((("j" "s"))(""))
    ((("j" "t"))(""))
    ((("j" "u"))(""))
    ((("j" "v"))(""))
    ((("j" "w"))(""))
    ((("j" "x"))(""))
    ((("j" "z"))("ͧ"))
    ((("k" ","))(""))
    ((("k" "."))(""))
    ((("k" "/"))(""))
    ((("k" ";"))(""))
    ((("k" "a"))(""))
    ((("k" "b"))(""))
    ((("k" "c"))("ƻ"))
    ((("k" "d"))(""))
    ((("k" "e"))(""))
    ((("k" "f"))(""))
    ((("k" "g"))(""))
    ((("k" "i"))(""))
    ((("k" "j"))(""))
    ((("k" "k"))(""))
    ((("k" "l"))(""))
    ((("k" "o"))(""))
    ((("k" "p"))(""))
    ((("k" "q"))(""))
    ((("k" "r"))(""))
    ((("k" "s"))(""))
    ((("k" "t"))(""))
    ((("k" "u"))(""))
    ((("k" "v"))(""))
    ((("k" "w"))(""))
    ((("k" "x"))(""))
    ((("k" "z"))(""))
    ((("l" ","))(""))
    ((("l" "."))(""))
    ((("l" "/"))("Ŭ"))
    ((("l" ";"))(""))
    ((("l" "a"))(""))
    ((("l" "b"))("¤"))
    ((("l" "c"))(""))
    ((("l" "d"))(""))
    ((("l" "e"))("Ȭ"))
    ((("l" "f"))("Ʊ"))
    ((("l" "g"))(""))
    ((("l" "i"))(""))
    ((("l" "j"))(""))
    ((("l" "k"))(""))
    ((("l" "l"))(""))
    ((("l" "o"))(""))
    ((("l" "p"))(""))
    ((("l" "q"))("Ϳ"))
    ((("l" "r"))(""))
    ((("l" "s"))(""))
    ((("l" "t"))(""))
    ((("l" "u"))(""))
    ((("l" "v"))(""))
    ((("l" "w"))(""))
    ((("l" "x"))(""))
    ((("l" "z"))(""))
    ((("m" ","))(""))
    ((("m" "."))(""))
    ((("m" "/"))(""))
    ((("m" ";"))(""))
    ((("m" "a"))(""))
    ((("m" "b"))(""))
    ((("m" "c"))(""))
    ((("m" "d"))(""))
    ((("m" "e"))(""))
    ((("m" "f"))("Ϻ"))
    ((("m" "g"))(""))
    ((("m" "i"))(""))
    ((("m" "j"))(""))
    ((("m" "k"))(""))
    ((("m" "l"))(""))
    ((("m" "o"))(""))
    ((("m" "p"))("ô"))
    ((("m" "q"))(""))
    ((("m" "r"))(""))
    ((("m" "s"))("´"))
    ((("m" "t"))(""))
    ((("m" "u"))("Ƿ"))
    ((("m" "v"))(""))
    ((("m" "w"))("¢"))
    ((("m" "x"))(""))
    ((("m" "z"))(""))
    ((("n" ","))(""))
    ((("n" "."))(""))
    ((("n" "/"))(""))
    ((("n" ";"))(""))
    ((("n" "a"))(""))
    ((("n" "b"))(""))
    ((("n" "c"))(""))
    ((("n" "d"))(""))
    ((("n" "e"))(""))
    ((("n" "f"))(""))
    ((("n" "g"))(""))
    ((("n" "i"))(""))
    ((("n" "j"))(""))
    ((("n" "k"))(""))
    ((("n" "l"))(""))
    ((("n" "o"))(""))
    ((("n" "p"))(""))
    ((("n" "q"))(""))
    ((("n" "r"))("Ⱦ"))
    ((("n" "s"))(""))
    ((("n" "t"))(""))
    ((("n" "u"))("ģ"))
    ((("n" "v"))(""))
    ((("n" "w"))(""))
    ((("n" "x"))(""))
    ((("n" "z"))(""))
    ((("o" ","))(""))
    ((("o" "."))(""))
    ((("o" "/"))(""))
    ((("o" ";"))(""))
    ((("o" "a"))(""))
    ((("o" "b"))("ͺ"))
    ((("o" "c"))(""))
    ((("o" "d"))("ϻ"))
    ((("o" "e"))(""))
    ((("o" "f"))(""))
    ((("o" "g"))("Ω"))
    ((("o" "i"))(""))
    ((("o" "j"))(""))
    ((("o" "k"))(""))
    ((("o" "l"))(""))
    ((("o" "o"))(""))
    ((("o" "p"))(""))
    ((("o" "q"))(""))
    ((("o" "r"))(""))
    ((("o" "s"))("ɴ"))
    ((("o" "t"))(""))
    ((("o" "u"))(""))
    ((("o" "v"))(""))
    ((("o" "w"))(""))
    ((("o" "x"))("ϫ"))
    ((("o" "z"))(""))
    ((("p" ","))(""))
    ((("p" "."))(""))
    ((("p" "/"))(""))
    ((("p" ";"))(""))
    ((("p" "a"))(""))
    ((("p" "b"))(""))
    ((("p" "c"))(""))
    ((("p" "d"))(""))
    ((("p" "e"))("Ŵ"))
    ((("p" "f"))(""))
    ((("p" "g"))(""))
    ((("p" "i"))("ǽ"))
    ((("p" "j"))(""))
    ((("p" "k"))("ž"))
    ((("p" "l"))(""))
    ((("p" "o"))(""))
    ((("p" "p"))(""))
    ((("p" "q"))(""))
    ((("p" "r"))(""))
    ((("p" "s"))(""))
    ((("p" "t"))(""))
    ((("p" "u"))(""))
    ((("p" "v"))(""))
    ((("p" "w"))("Ƭ"))
    ((("p" "x"))(""))
    ((("p" "z"))(""))
    ((("q" ","))(""))
    ((("q" "."))(""))
    ((("q" "/"))("Ÿ"))
    ((("q" ";"))(""))
    ((("q" "a"))("ǰ"))
    ((("q" "c"))(""))
    ((("q" "d"))(""))
    ((("q" "e"))(""))
    ((("q" "f"))(""))
    ((("q" "h"))(""))
    ((("q" "i"))(""))
    ((("q" "m"))(""))
    ((("q" "n"))("ɬ"))
    ((("q" "o"))(""))
    ((("q" "p"))(""))
    ((("q" "q"))(""))
    ((("q" "r"))(""))
    ((("q" "s"))(""))
    ((("q" "w"))(""))
    ((("q" "x"))(""))
    ((("q" "y"))(""))
    ((("q" "z"))(""))
    ((("r" ","))(""))
    ((("r" "."))(""))
    ((("r" "/"))("͢"))
    ((("r" ";"))(""))
    ((("r" "a"))(""))
    ((("r" "c"))(""))
    ((("r" "d"))(""))
    ((("r" "e"))("ͥ"))
    ((("r" "f"))(""))
    ((("r" "m"))(""))
    ((("r" "n"))(""))
    ((("r" "o"))(""))
    ((("r" "p"))(""))
    ((("r" "q"))(""))
    ((("r" "r"))(""))
    ((("r" "s"))(""))
    ((("r" "w"))(""))
    ((("r" "x"))(""))
    ((("r" "y"))(""))
    ((("r" "z"))("Ǯ"))
    ((("s" ","))(""))
    ((("s" "."))(""))
    ((("s" "/"))("­"))
    ((("s" ";"))(""))
    ((("s" "a"))(""))
    ((("s" "c"))(""))
    ((("s" "d"))("ͭ"))
    ((("s" "e"))(""))
    ((("s" "f"))(""))
    ((("s" "m"))(""))
    ((("s" "n"))(""))
    ((("s" "o"))("ȯ"))
    ((("s" "p"))(""))
    ((("s" "q"))(""))
    ((("s" "r"))(""))
    ((("s" "s"))("ʡ"))
    ((("s" "w"))(""))
    ((("s" "x"))(""))
    ((("s" "y"))(""))
    ((("s" "z"))(""))
    ((("t" ","))(""))
    ((("t" "."))(""))
    ((("t" "/"))("̣"))
    ((("t" ";"))(""))
    ((("t" "a"))(""))
    ((("t" "c"))(""))
    ((("t" "d"))(""))
    ((("t" "e"))(""))
    ((("t" "f"))(""))
    ((("t" "m"))("ȿ"))
    ((("t" "n"))(""))
    ((("t" "o"))("Ū"))
    ((("t" "p"))("ˡ"))
    ((("t" "q"))(""))
    ((("t" "r"))(""))
    ((("t" "s"))(""))
    ((("t" "w"))(""))
    ((("t" "x"))(""))
    ((("t" "y"))(""))
    ((("t" "z"))(""))
    ((("u" ","))(""))
    ((("u" "."))(""))
    ((("u" "/"))(""))
    ((("u" ";"))(""))
    ((("u" "a"))(""))
    ((("u" "b"))(""))
    ((("u" "c"))(""))
    ((("u" "d"))(""))
    ((("u" "e"))(""))
    ((("u" "f"))(""))
    ((("u" "g"))(""))
    ((("u" "i"))("ɽ"))
    ((("u" "j"))(""))
    ((("u" "k"))(""))
    ((("u" "l"))(""))
    ((("u" "o"))(""))
    ((("u" "p"))(""))
    ((("u" "q"))(""))
    ((("u" "r"))(""))
    ((("u" "s"))(""))
    ((("u" "t"))(""))
    ((("u" "u"))(""))
    ((("u" "v"))(""))
    ((("u" "w"))(""))
    ((("u" "x"))(""))
    ((("u" "z"))(""))
    ((("v" ","))(""))
    ((("v" "."))("Ͽ"))
    ((("v" "/"))(""))
    ((("v" ";"))(""))
    ((("v" "a"))(""))
    ((("v" "c"))(""))
    ((("v" "d"))(""))
    ((("v" "e"))(""))
    ((("v" "f"))(""))
    ((("v" "h"))(""))
    ((("v" "i"))(""))
    ((("v" "j"))(""))
    ((("v" "k"))(""))
    ((("v" "l"))(""))
    ((("v" "m"))(""))
    ((("v" "n"))(""))
    ((("v" "o"))(""))
    ((("v" "p"))(""))
    ((("v" "q"))(""))
    ((("v" "r"))(""))
    ((("v" "s"))(""))
    ((("v" "u"))(""))
    ((("v" "w"))(""))
    ((("v" "x"))(""))
    ((("v" "y"))(""))
    ((("v" "z"))(""))
    ((("w" ","))(""))
    ((("w" "."))(""))
    ((("w" "/"))(""))
    ((("w" ";"))(""))
    ((("w" "a"))(""))
    ((("w" "c"))(""))
    ((("w" "d"))(""))
    ((("w" "e"))(""))
    ((("w" "f"))(""))
    ((("w" "l"))(""))
    ((("w" "m"))(""))
    ((("w" "n"))(""))
    ((("w" "o"))(""))
    ((("w" "p"))("ͽ"))
    ((("w" "q"))(""))
    ((("w" "r"))(""))
    ((("w" "s"))(""))
    ((("w" "w"))(""))
    ((("w" "x"))("ˬ"))
    ((("w" "y"))(""))
    ((("w" "z"))(""))
    ((("x" ","))("̿"))
    ((("x" "."))("Ƴ"))
    ((("x" "/"))(""))
    ((("x" ";"))(""))
    ((("x" "a"))(""))
    ((("x" "c"))(""))
    ((("x" "d"))(""))
    ((("x" "e"))(""))
    ((("x" "f"))(""))
    ((("x" "h"))(""))
    ((("x" "i"))(""))
    ((("x" "j"))(""))
    ((("x" "k"))(""))
    ((("x" "l"))(""))
    ((("x" "m"))(""))
    ((("x" "n"))("ǧ"))
    ((("x" "o"))(""))
    ((("x" "p"))(""))
    ((("x" "q"))(""))
    ((("x" "r"))("ͷ"))
    ((("x" "s"))("ñ"))
    ((("x" "u"))(""))
    ((("x" "w"))("û"))
    ((("x" "x"))(""))
    ((("x" "y"))(""))
    ((("x" "z"))(""))
    ((("y" ","))(""))
    ((("y" "."))(""))
    ((("y" "/"))(""))
    ((("y" ";"))(""))
    ((("y" "a"))(""))
    ((("y" "b"))(""))
    ((("y" "c"))(""))
    ((("y" "d"))(""))
    ((("y" "e"))(""))
    ((("y" "f"))(""))
    ((("y" "g"))(""))
    ((("y" "i"))("̱"))
    ((("y" "j"))(""))
    ((("y" "k"))(""))
    ((("y" "l"))(""))
    ((("y" "o"))(""))
    ((("y" "p"))(""))
    ((("y" "q"))(""))
    ((("y" "r"))("Į"))
    ((("y" "s"))(""))
    ((("y" "t"))(""))
    ((("y" "u"))(""))
    ((("y" "v"))(""))
    ((("y" "w"))(""))
    ((("y" "x"))(""))
    ((("y" "z"))(""))
    ((("z" ","))(""))
    ((("z" "."))("ȴ"))
    ((("z" "/"))(""))
    ((("z" ";"))(""))
    ((("z" "a"))(""))
    ((("z" "c"))(""))
    ((("z" "d"))("ɾ"))
    ((("z" "e"))(""))
    ((("z" "f"))("Ƥ"))
    ((("z" "h"))("Ƚ"))
    ((("z" "i"))(""))
    ((("z" "j"))(""))
    ((("z" "k"))(""))
    ((("z" "l"))("Ǥ"))
    ((("z" "m"))(""))
    ((("z" "n"))(""))
    ((("z" "o"))(""))
    ((("z" "p"))("ã"))
    ((("z" "q"))(""))
    ((("z" "r"))(""))
    ((("z" "s"))(""))
    ((("z" "u"))(""))
    ((("z" "w"))("΢"))
    ((("z" "x"))(""))
    ((("z" "y"))(""))
    ((("z" "z"))(""))
    ((("," "h" "a"))(""))
    ((("," "h" "b"))(""))
    ((("," "h" "c"))(""))
    ((("," "h" "d"))("ü"))
    ((("," "h" "e"))(""))
    ((("," "h" "f"))(""))
    ((("," "h" "g"))(""))
    ((("," "h" "q"))("Ϥ"))
    ((("," "h" "r"))("ǳ"))
    ((("," "h" "s"))(""))
    ((("," "h" "t"))(""))
    ((("," "h" "v"))(""))
    ((("," "h" "w"))(""))
    ((("," "h" "x"))(""))
    ((("," "h" "z"))(""))
    ((("," "m" "a"))(""))
    ((("," "m" "b"))(""))
    ((("," "m" "c"))(""))
    ((("," "m" "d"))(""))
    ((("," "m" "e"))("ʢ"))
    ((("," "m" "f"))(""))
    ((("," "m" "g"))(""))
    ((("," "m" "q"))(""))
    ((("," "m" "r"))(""))
    ((("," "m" "s"))("ȶ"))
    ((("," "m" "t"))(""))
    ((("," "m" "v"))(""))
    ((("," "m" "w"))(""))
    ((("," "m" "x"))(""))
    ((("," "m" "z"))(""))
    ((("," "n" "a"))(""))
    ((("," "n" "b"))(""))
    ((("," "n" "c"))(""))
    ((("," "n" "d"))("͡"))
    ((("," "n" "e"))(""))
    ((("," "n" "f"))(""))
    ((("," "n" "g"))("γ"))
    ((("," "n" "q"))(""))
    ((("," "n" "r"))(""))
    ((("," "n" "s"))(""))
    ((("," "n" "t"))(""))
    ((("," "n" "v"))("Ͻ"))
    ((("," "n" "w"))(""))
    ((("," "n" "x"))(""))
    ((("," "n" "z"))(""))
    ((("," "y" "a"))(""))
    ((("," "y" "b"))(""))
    ((("," "y" "c"))(""))
    ((("," "y" "d"))(""))
    ((("," "y" "e"))("̸"))
    ((("," "y" "f"))(""))
    ((("," "y" "g"))(""))
    ((("," "y" "q"))(""))
    ((("," "y" "r"))(""))
    ((("," "y" "s"))(""))
    ((("," "y" "t"))(""))
    ((("," "y" "v"))(""))
    ((("," "y" "w"))(""))
    ((("," "y" "x"))(""))
    ((("," "y" "z"))(""))
    ((("." "h" "a"))(""))
    ((("." "h" "b"))("ȭ"))
    ((("." "h" "c"))(""))
    ((("." "h" "d"))(""))
    ((("." "h" "e"))(""))
    ((("." "h" "f"))(""))
    ((("." "h" "g"))(""))
    ((("." "h" "q"))(""))
    ((("." "h" "r"))(""))
    ((("." "h" "s"))(""))
    ((("." "h" "t"))(""))
    ((("." "h" "v"))(""))
    ((("." "h" "w"))("κ"))
    ((("." "h" "x"))(""))
    ((("." "h" "z"))(""))
    ((("." "m" "a"))("˨"))
    ((("." "m" "b"))(""))
    ((("." "m" "c"))("ġ"))
    ((("." "m" "d"))(""))
    ((("." "m" "e"))(""))
    ((("." "m" "f"))(""))
    ((("." "m" "g"))(""))
    ((("." "m" "q"))(""))
    ((("." "m" "r"))(""))
    ((("." "m" "s"))(""))
    ((("." "m" "t"))(""))
    ((("." "m" "v"))(""))
    ((("." "m" "w"))(""))
    ((("." "m" "x"))(""))
    ((("." "m" "z"))("ĵ"))
    ((("." "n" "a"))(""))
    ((("." "n" "b"))(""))
    ((("." "n" "c"))(""))
    ((("." "n" "d"))(""))
    ((("." "n" "e"))(""))
    ((("." "n" "f"))(""))
    ((("." "n" "g"))(""))
    ((("." "n" "q"))("ˣ"))
    ((("." "n" "r"))(""))
    ((("." "n" "s"))(""))
    ((("." "n" "t"))(""))
    ((("." "n" "v"))(""))
    ((("." "n" "w"))(""))
    ((("." "n" "x"))(""))
    ((("." "n" "z"))(""))
    ((("." "y" "a"))(""))
    ((("." "y" "b"))(""))
    ((("." "y" "c"))(""))
    ((("." "y" "d"))(""))
    ((("." "y" "e"))(""))
    ((("." "y" "f"))("į"))
    ((("." "y" "g"))(""))
    ((("." "y" "q"))("˪"))
    ((("." "y" "r"))("ͪ"))
    ((("." "y" "s"))(""))
    ((("." "y" "t"))(""))
    ((("." "y" "v"))(""))
    ((("." "y" "w"))(""))
    ((("." "y" "x"))("ɰ"))
    ((("." "y" "z"))(""))
    ((("/" "h" "a"))(""))
    ((("/" "h" "b"))(""))
    ((("/" "h" "c"))(""))
    ((("/" "h" "d"))(""))
    ((("/" "h" "e"))(""))
    ((("/" "h" "f"))("̦"))
    ((("/" "h" "g"))(""))
    ((("/" "h" "q"))(""))
    ((("/" "h" "r"))(""))
    ((("/" "h" "s"))(""))
    ((("/" "h" "t"))(""))
    ((("/" "h" "v"))(""))
    ((("/" "h" "w"))(""))
    ((("/" "h" "x"))("ĸ"))
    ((("/" "h" "z"))(""))
    ((("/" "m" "a"))(""))
    ((("/" "m" "b"))("ο"))
    ((("/" "m" "c"))(""))
    ((("/" "m" "d"))(""))
    ((("/" "m" "e"))(""))
    ((("/" "m" "f"))(""))
    ((("/" "m" "g"))(""))
    ((("/" "m" "q"))(""))
    ((("/" "m" "r"))(""))
    ((("/" "m" "s"))(""))
    ((("/" "m" "t"))(""))
    ((("/" "m" "v"))(""))
    ((("/" "m" "w"))("Ů"))
    ((("/" "m" "x"))("̧"))
    ((("/" "m" "z"))(""))
    ((("/" "n" "a"))(""))
    ((("/" "n" "b"))(""))
    ((("/" "n" "c"))(""))
    ((("/" "n" "d"))(""))
    ((("/" "n" "e"))(""))
    ((("/" "n" "f"))(""))
    ((("/" "n" "g"))("˫"))
    ((("/" "n" "q"))(""))
    ((("/" "n" "r"))(""))
    ((("/" "n" "s"))("ζ"))
    ((("/" "n" "t"))(""))
    ((("/" "n" "v"))(""))
    ((("/" "n" "w"))(""))
    ((("/" "n" "x"))(""))
    ((("/" "n" "z"))(""))
    ((("/" "y" "a"))(""))
    ((("/" "y" "b"))("ì"))
    ((("/" "y" "c"))(""))
    ((("/" "y" "d"))(""))
    ((("/" "y" "e"))(""))
    ((("/" "y" "f"))(""))
    ((("/" "y" "g"))(""))
    ((("/" "y" "q"))(""))
    ((("/" "y" "r"))(""))
    ((("/" "y" "s"))(""))
    ((("/" "y" "t"))(""))
    ((("/" "y" "v"))("ȫ"))
    ((("/" "y" "w"))(""))
    ((("/" "y" "x"))(""))
    ((("/" "y" "z"))(""))
    (((";" "h" "a"))(""))
    (((";" "h" "b"))(""))
    (((";" "h" "c"))(""))
    (((";" "h" "d"))(""))
    (((";" "h" "e"))(""))
    (((";" "h" "f"))(""))
    (((";" "h" "g"))(""))
    (((";" "h" "q"))(""))
    (((";" "h" "r"))(""))
    (((";" "h" "s"))(""))
    (((";" "h" "t"))(""))
    (((";" "h" "v"))(""))
    (((";" "h" "w"))(""))
    (((";" "h" "x"))(""))
    (((";" "h" "z"))(""))
    (((";" "m" "a"))(""))
    (((";" "m" "b"))(""))
    (((";" "m" "c"))("ȥ"))
    (((";" "m" "d"))(""))
    (((";" "m" "e"))(""))
    (((";" "m" "f"))("ί"))
    (((";" "m" "g"))(""))
    (((";" "m" "q"))(""))
    (((";" "m" "r"))("ʮ"))
    (((";" "m" "s"))("Ʒ"))
    (((";" "m" "t"))(""))
    (((";" "m" "v"))(""))
    (((";" "m" "w"))(""))
    (((";" "m" "x"))(""))
    (((";" "m" "z"))(""))
    (((";" "n" "a"))(""))
    (((";" "n" "b"))(""))
    (((";" "n" "c"))(""))
    (((";" "n" "d"))("ʶ"))
    (((";" "n" "e"))(""))
    (((";" "n" "f"))(""))
    (((";" "n" "g"))(""))
    (((";" "n" "q"))(""))
    (((";" "n" "r"))(""))
    (((";" "n" "s"))(""))
    (((";" "n" "t"))("ʨ"))
    (((";" "n" "v"))(""))
    (((";" "n" "w"))(""))
    (((";" "n" "x"))(""))
    (((";" "n" "z"))(""))
    (((";" "y" "a"))(""))
    (((";" "y" "b"))(""))
    (((";" "y" "c"))(""))
    (((";" "y" "d"))(""))
    (((";" "y" "e"))(""))
    (((";" "y" "f"))(""))
    (((";" "y" "g"))(""))
    (((";" "y" "q"))(""))
    (((";" "y" "r"))(""))
    (((";" "y" "s"))(""))
    (((";" "y" "t"))(""))
    (((";" "y" "v"))(""))
    (((";" "y" "w"))(""))
    (((";" "y" "x"))(""))
    (((";" "y" "z"))(""))
    ((("a" "b" ","))(""))
    ((("a" "b" "."))(""))
    ((("a" "b" "/"))(""))
    ((("a" "b" ";"))("ʯ"))
    ((("a" "b" "h"))(""))
    ((("a" "b" "i"))("µ"))
    ((("a" "b" "j"))(""))
    ((("a" "b" "k"))(""))
    ((("a" "b" "l"))(""))
    ((("a" "b" "m"))(""))
    ((("a" "b" "n"))(""))
    ((("a" "b" "o"))(""))
    ((("a" "b" "p"))(""))
    ((("a" "b" "u"))("ǡ"))
    ((("a" "b" "y"))(""))
    ((("a" "g" ","))("å"))
    ((("a" "g" "."))(""))
    ((("a" "g" "/"))(""))
    ((("a" "g" ";"))(""))
    ((("a" "g" "h"))(""))
    ((("a" "g" "i"))(""))
    ((("a" "g" "j"))(""))
    ((("a" "g" "k"))(""))
    ((("a" "g" "l"))(""))
    ((("a" "g" "m"))(""))
    ((("a" "g" "n"))(""))
    ((("a" "g" "o"))(""))
    ((("a" "g" "p"))("ź"))
    ((("a" "g" "u"))(""))
    ((("a" "g" "y"))("Ǽ"))
    ((("a" "t" ","))(""))
    ((("a" "t" "."))("ȷ"))
    ((("a" "t" "/"))(""))
    ((("a" "t" ";"))(""))
    ((("a" "t" "h"))(""))
    ((("a" "t" "i"))(""))
    ((("a" "t" "j"))(""))
    ((("a" "t" "k"))(""))
    ((("a" "t" "l"))(""))
    ((("a" "t" "m"))(""))
    ((("a" "t" "n"))(""))
    ((("a" "t" "o"))(""))
    ((("a" "t" "p"))(""))
    ((("a" "t" "u"))(""))
    ((("a" "t" "y"))(""))
    ((("a" "v" ","))(""))
    ((("a" "v" "."))(""))
    ((("a" "v" "/"))(""))
    ((("a" "v" ";"))(""))
    ((("a" "v" "h"))(""))
    ((("a" "v" "i"))(""))
    ((("a" "v" "j"))("ï"))
    ((("a" "v" "k"))(""))
    ((("a" "v" "l"))(""))
    ((("a" "v" "m"))(""))
    ((("a" "v" "n"))("ɿ"))
    ((("a" "v" "o"))(""))
    ((("a" "v" "p"))(""))
    ((("a" "v" "u"))(""))
    ((("a" "v" "y"))(""))
    ((("b" "b" ","))(""))
    ((("b" "b" "."))("ÿ"))
    ((("b" "b" "/"))(""))
    ((("b" "b" ";"))("̶"))
    ((("b" "b" "h"))(""))
    ((("b" "b" "i"))(""))
    ((("b" "b" "j"))(""))
    ((("b" "b" "k"))(""))
    ((("b" "b" "l"))(""))
    ((("b" "b" "m"))(""))
    ((("b" "b" "n"))("ǿ"))
    ((("b" "b" "o"))(""))
    ((("b" "b" "p"))(""))
    ((("b" "b" "u"))(""))
    ((("b" "b" "y"))(""))
    ((("b" "g" ","))(""))
    ((("b" "g" "."))(""))
    ((("b" "g" "/"))(""))
    ((("b" "g" ";"))(""))
    ((("b" "g" "h"))(""))
    ((("b" "g" "i"))(""))
    ((("b" "g" "j"))("ͣ"))
    ((("b" "g" "k"))(""))
    ((("b" "g" "l"))(""))
    ((("b" "g" "m"))(""))
    ((("b" "g" "n"))(""))
    ((("b" "g" "o"))(""))
    ((("b" "g" "p"))(""))
    ((("b" "g" "u"))(""))
    ((("b" "g" "y"))(""))
    ((("b" "t" ","))(""))
    ((("b" "t" "."))(""))
    ((("b" "t" "/"))(""))
    ((("b" "t" ";"))("ó"))
    ((("b" "t" "h"))(""))
    ((("b" "t" "i"))(""))
    ((("b" "t" "j"))(""))
    ((("b" "t" "k"))(""))
    ((("b" "t" "l"))(""))
    ((("b" "t" "m"))(""))
    ((("b" "t" "n"))(""))
    ((("b" "t" "o"))(""))
    ((("b" "t" "p"))(""))
    ((("b" "t" "u"))(""))
    ((("b" "t" "y"))(""))
    ((("b" "v" ","))("̪"))
    ((("b" "v" "."))(""))
    ((("b" "v" "/"))(""))
    ((("b" "v" ";"))(""))
    ((("b" "v" "h"))(""))
    ((("b" "v" "i"))(""))
    ((("b" "v" "j"))(""))
    ((("b" "v" "k"))(""))
    ((("b" "v" "l"))(""))
    ((("b" "v" "m"))(""))
    ((("b" "v" "n"))(""))
    ((("b" "v" "o"))(""))
    ((("b" "v" "p"))(""))
    ((("b" "v" "u"))(""))
    ((("b" "v" "y"))(""))
    ((("c" "b" ","))(""))
    ((("c" "b" "."))(""))
    ((("c" "b" "/"))(""))
    ((("c" "b" ";"))(""))
    ((("c" "b" "h"))(""))
    ((("c" "b" "i"))("Ž"))
    ((("c" "b" "j"))("ű"))
    ((("c" "b" "k"))(""))
    ((("c" "b" "l"))(""))
    ((("c" "b" "m"))(""))
    ((("c" "b" "n"))(""))
    ((("c" "b" "o"))(""))
    ((("c" "b" "p"))(""))
    ((("c" "b" "u"))("ƽ"))
    ((("c" "b" "y"))(""))
    ((("c" "g" ","))(""))
    ((("c" "g" "."))(""))
    ((("c" "g" "/"))(""))
    ((("c" "g" ";"))(""))
    ((("c" "g" "h"))(""))
    ((("c" "g" "i"))(""))
    ((("c" "g" "j"))("Τ"))
    ((("c" "g" "k"))(""))
    ((("c" "g" "l"))("Ű"))
    ((("c" "g" "m"))("Ʃ"))
    ((("c" "g" "n"))("ƥ"))
    ((("c" "g" "o"))(""))
    ((("c" "g" "p"))(""))
    ((("c" "g" "u"))(""))
    ((("c" "g" "y"))(""))
    ((("c" "t" ","))(""))
    ((("c" "t" "."))(""))
    ((("c" "t" "/"))(""))
    ((("c" "t" ";"))("ʤ"))
    ((("c" "t" "h"))(""))
    ((("c" "t" "i"))("β"))
    ((("c" "t" "j"))(""))
    ((("c" "t" "k"))(""))
    ((("c" "t" "l"))(""))
    ((("c" "t" "m"))(""))
    ((("c" "t" "n"))("ɳ"))
    ((("c" "t" "o"))(""))
    ((("c" "t" "p"))(""))
    ((("c" "t" "u"))(""))
    ((("c" "t" "y"))(""))
    ((("c" "v" ","))(""))
    ((("c" "v" "."))(""))
    ((("c" "v" "/"))(""))
    ((("c" "v" ";"))(""))
    ((("c" "v" "h"))(""))
    ((("c" "v" "i"))(""))
    ((("c" "v" "j"))(""))
    ((("c" "v" "k"))(""))
    ((("c" "v" "l"))(""))
    ((("c" "v" "m"))(""))
    ((("c" "v" "n"))(""))
    ((("c" "v" "o"))(""))
    ((("c" "v" "p"))(""))
    ((("c" "v" "u"))(""))
    ((("c" "v" "y"))(""))
    ((("d" "b" ","))(""))
    ((("d" "b" "."))(""))
    ((("d" "b" "/"))(""))
    ((("d" "b" ";"))(""))
    ((("d" "b" "h"))(""))
    ((("d" "b" "i"))(""))
    ((("d" "b" "j"))(""))
    ((("d" "b" "k"))(""))
    ((("d" "b" "l"))(""))
    ((("d" "b" "m"))(""))
    ((("d" "b" "n"))(""))
    ((("d" "b" "o"))("˧"))
    ((("d" "b" "p"))(""))
    ((("d" "b" "u"))(""))
    ((("d" "b" "y"))("̡"))
    ((("d" "g" ","))(""))
    ((("d" "g" "."))("˴"))
    ((("d" "g" "/"))(""))
    ((("d" "g" ";"))(""))
    ((("d" "g" "h"))(""))
    ((("d" "g" "i"))(""))
    ((("d" "g" "j"))(""))
    ((("d" "g" "k"))(""))
    ((("d" "g" "l"))(""))
    ((("d" "g" "m"))("¸"))
    ((("d" "g" "n"))("Ȣ"))
    ((("d" "g" "o"))(""))
    ((("d" "g" "p"))("Ȩ"))
    ((("d" "g" "u"))(""))
    ((("d" "g" "y"))(""))
    ((("d" "t" ","))(""))
    ((("d" "t" "."))(""))
    ((("d" "t" "/"))(""))
    ((("d" "t" ";"))("æ"))
    ((("d" "t" "h"))(""))
    ((("d" "t" "i"))(""))
    ((("d" "t" "j"))(""))
    ((("d" "t" "k"))(""))
    ((("d" "t" "l"))(""))
    ((("d" "t" "m"))("Ȫ"))
    ((("d" "t" "n"))(""))
    ((("d" "t" "o"))(""))
    ((("d" "t" "p"))(""))
    ((("d" "t" "u"))(""))
    ((("d" "t" "y"))(""))
    ((("d" "v" ","))(""))
    ((("d" "v" "."))(""))
    ((("d" "v" "/"))(""))
    ((("d" "v" ";"))(""))
    ((("d" "v" "h"))(""))
    ((("d" "v" "i"))(""))
    ((("d" "v" "j"))(""))
    ((("d" "v" "k"))(""))
    ((("d" "v" "l"))(""))
    ((("d" "v" "m"))(""))
    ((("d" "v" "n"))(""))
    ((("d" "v" "o"))(""))
    ((("d" "v" "p"))(""))
    ((("d" "v" "u"))("δ"))
    ((("d" "v" "y"))("ä"))
    ((("e" "b" ","))(""))
    ((("e" "b" "."))(""))
    ((("e" "b" "/"))(""))
    ((("e" "b" ";"))(""))
    ((("e" "b" "h"))(""))
    ((("e" "b" "i"))(""))
    ((("e" "b" "j"))(""))
    ((("e" "b" "k"))(""))
    ((("e" "b" "l"))("ȱ"))
    ((("e" "b" "m"))("ʺ"))
    ((("e" "b" "n"))(""))
    ((("e" "b" "o"))(""))
    ((("e" "b" "p"))(""))
    ((("e" "b" "u"))(""))
    ((("e" "b" "y"))(""))
    ((("e" "g" ","))(""))
    ((("e" "g" "."))(""))
    ((("e" "g" "/"))(""))
    ((("e" "g" ";"))(""))
    ((("e" "g" "h"))(""))
    ((("e" "g" "i"))(""))
    ((("e" "g" "j"))(""))
    ((("e" "g" "k"))(""))
    ((("e" "g" "l"))(""))
    ((("e" "g" "m"))(""))
    ((("e" "g" "n"))(""))
    ((("e" "g" "o"))(""))
    ((("e" "g" "p"))(""))
    ((("e" "g" "u"))(""))
    ((("e" "g" "y"))("ú"))
    ((("e" "t" ","))("ά"))
    ((("e" "t" "."))(""))
    ((("e" "t" "/"))(""))
    ((("e" "t" ";"))("Ǿ"))
    ((("e" "t" "h"))(""))
    ((("e" "t" "i"))(""))
    ((("e" "t" "j"))(""))
    ((("e" "t" "k"))(""))
    ((("e" "t" "l"))("°"))
    ((("e" "t" "m"))(""))
    ((("e" "t" "n"))(""))
    ((("e" "t" "o"))(""))
    ((("e" "t" "p"))(""))
    ((("e" "t" "u"))(""))
    ((("e" "t" "y"))(""))
    ((("e" "v" ","))(""))
    ((("e" "v" "."))(""))
    ((("e" "v" "/"))(""))
    ((("e" "v" ";"))(""))
    ((("e" "v" "h"))(""))
    ((("e" "v" "i"))(""))
    ((("e" "v" "j"))("İ"))
    ((("e" "v" "k"))("ǵ"))
    ((("e" "v" "l"))(""))
    ((("e" "v" "m"))(""))
    ((("e" "v" "n"))(""))
    ((("e" "v" "o"))(""))
    ((("e" "v" "p"))(""))
    ((("e" "v" "u"))(""))
    ((("e" "v" "y"))(""))
    ((("f" "b" ","))(""))
    ((("f" "b" "."))(""))
    ((("f" "b" "/"))(""))
    ((("f" "b" ";"))(""))
    ((("f" "b" "h"))(""))
    ((("f" "b" "i"))("̼"))
    ((("f" "b" "j"))(""))
    ((("f" "b" "k"))(""))
    ((("f" "b" "l"))(""))
    ((("f" "b" "m"))(""))
    ((("f" "b" "n"))(""))
    ((("f" "b" "o"))(""))
    ((("f" "b" "p"))("ƶ"))
    ((("f" "b" "u"))(""))
    ((("f" "b" "y"))(""))
    ((("f" "g" ","))(""))
    ((("f" "g" "."))("Ũ"))
    ((("f" "g" "/"))(""))
    ((("f" "g" ";"))(""))
    ((("f" "g" "h"))(""))
    ((("f" "g" "i"))(""))
    ((("f" "g" "j"))(""))
    ((("f" "g" "k"))(""))
    ((("f" "g" "l"))(""))
    ((("f" "g" "m"))(""))
    ((("f" "g" "n"))(""))
    ((("f" "g" "o"))(""))
    ((("f" "g" "p"))(""))
    ((("f" "g" "u"))(""))
    ((("f" "g" "y"))(""))
    ((("f" "t" ","))(""))
    ((("f" "t" "."))("̯"))
    ((("f" "t" "/"))(""))
    ((("f" "t" ";"))(""))
    ((("f" "t" "h"))(""))
    ((("f" "t" "i"))(""))
    ((("f" "t" "j"))(""))
    ((("f" "t" "k"))(""))
    ((("f" "t" "l"))(""))
    ((("f" "t" "m"))("ϲ"))
    ((("f" "t" "n"))(""))
    ((("f" "t" "o"))("§"))
    ((("f" "t" "p"))(""))
    ((("f" "t" "u"))(""))
    ((("f" "t" "y"))(""))
    ((("f" "v" ","))(""))
    ((("f" "v" "."))(""))
    ((("f" "v" "/"))(""))
    ((("f" "v" ";"))(""))
    ((("f" "v" "h"))("Ŧ"))
    ((("f" "v" "i"))(""))
    ((("f" "v" "j"))(""))
    ((("f" "v" "k"))(""))
    ((("f" "v" "l"))(""))
    ((("f" "v" "m"))("ų"))
    ((("f" "v" "n"))(""))
    ((("f" "v" "o"))(""))
    ((("f" "v" "p"))(""))
    ((("f" "v" "u"))(""))
    ((("f" "v" "y"))(""))
    ((("g" "b" ","))(""))
    ((("g" "b" "."))(""))
    ((("g" "b" "/"))(""))
    ((("g" "b" ";"))(""))
    ((("g" "b" "h"))(""))
    ((("g" "b" "i"))(""))
    ((("g" "b" "j"))("Ƽ"))
    ((("g" "b" "k"))(""))
    ((("g" "b" "l"))(""))
    ((("g" "b" "m"))(""))
    ((("g" "b" "n"))(""))
    ((("g" "b" "o"))(""))
    ((("g" "b" "p"))(""))
    ((("g" "b" "u"))(""))
    ((("g" "b" "y"))(""))
    ((("g" "g" ","))(""))
    ((("g" "g" "."))(""))
    ((("g" "g" "/"))("Ĩ"))
    ((("g" "g" ";"))(""))
    ((("g" "g" "h"))(""))
    ((("g" "g" "i"))(""))
    ((("g" "g" "j"))(""))
    ((("g" "g" "k"))(""))
    ((("g" "g" "l"))(""))
    ((("g" "g" "m"))(""))
    ((("g" "g" "n"))(""))
    ((("g" "g" "o"))(""))
    ((("g" "g" "p"))(""))
    ((("g" "g" "u"))(""))
    ((("g" "g" "y"))("ɮ"))
    ((("g" "t" ","))(""))
    ((("g" "t" "."))(""))
    ((("g" "t" "/"))(""))
    ((("g" "t" ";"))(""))
    ((("g" "t" "h"))(""))
    ((("g" "t" "i"))(""))
    ((("g" "t" "j"))(""))
    ((("g" "t" "k"))("ŵ"))
    ((("g" "t" "l"))(""))
    ((("g" "t" "m"))(""))
    ((("g" "t" "n"))(""))
    ((("g" "t" "o"))(""))
    ((("g" "t" "p"))(""))
    ((("g" "t" "u"))(""))
    ((("g" "t" "y"))(""))
    ((("g" "v" ","))(""))
    ((("g" "v" "."))(""))
    ((("g" "v" "/"))(""))
    ((("g" "v" ";"))(""))
    ((("g" "v" "h"))("ǻ"))
    ((("g" "v" "i"))(""))
    ((("g" "v" "j"))(""))
    ((("g" "v" "k"))(""))
    ((("g" "v" "l"))(""))
    ((("g" "v" "m"))(""))
    ((("g" "v" "n"))(""))
    ((("g" "v" "o"))(""))
    ((("g" "v" "p"))(""))
    ((("g" "v" "u"))(""))
    ((("g" "v" "y"))("Ħ"))
    ((("h" "h" "a"))(""))
    ((("h" "h" "b"))(""))
    ((("h" "h" "c"))(""))
    ((("h" "h" "d"))(""))
    ((("h" "h" "e"))(""))
    ((("h" "h" "f"))(""))
    ((("h" "h" "g"))(""))
    ((("h" "h" "q"))(""))
    ((("h" "h" "r"))(""))
    ((("h" "h" "s"))(""))
    ((("h" "h" "t"))(""))
    ((("h" "h" "v"))(""))
    ((("h" "h" "w"))(""))
    ((("h" "h" "x"))(""))
    ((("h" "h" "z"))(""))
    ((("h" "m" "a"))(""))
    ((("h" "m" "b"))(""))
    ((("h" "m" "c"))("ϵ"))
    ((("h" "m" "d"))(""))
    ((("h" "m" "e"))("ø"))
    ((("h" "m" "f"))(""))
    ((("h" "m" "g"))("Ǻ"))
    ((("h" "m" "q"))(""))
    ((("h" "m" "r"))(""))
    ((("h" "m" "s"))(""))
    ((("h" "m" "t"))("ĩ"))
    ((("h" "m" "v"))(""))
    ((("h" "m" "w"))(""))
    ((("h" "m" "x"))(""))
    ((("h" "m" "z"))(""))
    ((("h" "n" "a"))(""))
    ((("h" "n" "b"))(""))
    ((("h" "n" "c"))(""))
    ((("h" "n" "d"))(""))
    ((("h" "n" "e"))(""))
    ((("h" "n" "f"))("̲"))
    ((("h" "n" "g"))(""))
    ((("h" "n" "q"))(""))
    ((("h" "n" "r"))(""))
    ((("h" "n" "s"))(""))
    ((("h" "n" "t"))("ʳ"))
    ((("h" "n" "v"))(""))
    ((("h" "n" "w"))(""))
    ((("h" "n" "x"))(""))
    ((("h" "n" "z"))(""))
    ((("h" "y" "a"))(""))
    ((("h" "y" "b"))(""))
    ((("h" "y" "c"))(""))
    ((("h" "y" "d"))(""))
    ((("h" "y" "e"))(""))
    ((("h" "y" "f"))(""))
    ((("h" "y" "g"))(""))
    ((("h" "y" "q"))("ɤ"))
    ((("h" "y" "r"))(""))
    ((("h" "y" "s"))(""))
    ((("h" "y" "t"))(""))
    ((("h" "y" "v"))(""))
    ((("h" "y" "w"))(""))
    ((("h" "y" "x"))(""))
    ((("h" "y" "z"))(""))
    ((("i" "h" "a"))(""))
    ((("i" "h" "b"))(""))
    ((("i" "h" "c"))("ƨ"))
    ((("i" "h" "d"))(""))
    ((("i" "h" "e"))("ɧ"))
    ((("i" "h" "f"))(""))
    ((("i" "h" "g"))(""))
    ((("i" "h" "q"))(""))
    ((("i" "h" "r"))(""))
    ((("i" "h" "s"))("˼"))
    ((("i" "h" "t"))(""))
    ((("i" "h" "v"))(""))
    ((("i" "h" "w"))(";"))
    ((("i" "h" "x"))(""))
    ((("i" "h" "z"))(""))
    ((("i" "m" "a"))(""))
    ((("i" "m" "b"))(""))
    ((("i" "m" "c"))(""))
    ((("i" "m" "d"))(""))
    ((("i" "m" "e"))(""))
    ((("i" "m" "f"))(""))
    ((("i" "m" "g"))(""))
    ((("i" "m" "q"))(""))
    ((("i" "m" "r"))(""))
    ((("i" "m" "s"))(""))
    ((("i" "m" "t"))(""))
    ((("i" "m" "v"))(""))
    ((("i" "m" "w"))(""))
    ((("i" "m" "x"))(""))
    ((("i" "m" "z"))(""))
    ((("i" "n" "a"))(""))
    ((("i" "n" "b"))(""))
    ((("i" "n" "c"))(""))
    ((("i" "n" "d"))("ħ"))
    ((("i" "n" "e"))(""))
    ((("i" "n" "f"))(""))
    ((("i" "n" "g"))("Ǧ"))
    ((("i" "n" "q"))(""))
    ((("i" "n" "r"))("ˤ"))
    ((("i" "n" "s"))(""))
    ((("i" "n" "t"))(""))
    ((("i" "n" "v"))(""))
    ((("i" "n" "w"))(""))
    ((("i" "n" "x"))(""))
    ((("i" "n" "z"))(""))
    ((("i" "y" "a"))(""))
    ((("i" "y" "b"))(""))
    ((("i" "y" "c"))(""))
    ((("i" "y" "d"))(""))
    ((("i" "y" "e"))(""))
    ((("i" "y" "f"))(""))
    ((("i" "y" "g"))("š"))
    ((("i" "y" "q"))("ν"))
    ((("i" "y" "r"))("Ļ"))
    ((("i" "y" "s"))(""))
    ((("i" "y" "t"))(""))
    ((("i" "y" "v"))(""))
    ((("i" "y" "w"))("ʴ"))
    ((("i" "y" "x"))("Ĳ"))
    ((("i" "y" "z"))(""))
    ((("j" "h" "a"))(""))
    ((("j" "h" "b"))(""))
    ((("j" "h" "c"))(""))
    ((("j" "h" "d"))(""))
    ((("j" "h" "e"))(""))
    ((("j" "h" "f"))(""))
    ((("j" "h" "g"))(""))
    ((("j" "h" "q"))(""))
    ((("j" "h" "r"))(""))
    ((("j" "h" "s"))(""))
    ((("j" "h" "t"))(""))
    ((("j" "h" "v"))(""))
    ((("j" "h" "w"))(""))
    ((("j" "h" "x"))(""))
    ((("j" "h" "z"))("º"))
    ((("j" "m" "a"))("ƹ"))
    ((("j" "m" "b"))(""))
    ((("j" "m" "c"))(""))
    ((("j" "m" "d"))(""))
    ((("j" "m" "e"))(""))
    ((("j" "m" "f"))(""))
    ((("j" "m" "g"))("Ƹ"))
    ((("j" "m" "q"))(""))
    ((("j" "m" "r"))(""))
    ((("j" "m" "s"))(""))
    ((("j" "m" "t"))(""))
    ((("j" "m" "v"))(""))
    ((("j" "m" "w"))(""))
    ((("j" "m" "x"))(""))
    ((("j" "m" "z"))(""))
    ((("j" "n" "a"))("ĳ"))
    ((("j" "n" "b"))(""))
    ((("j" "n" "c"))(""))
    ((("j" "n" "d"))(""))
    ((("j" "n" "e"))(""))
    ((("j" "n" "f"))(""))
    ((("j" "n" "g"))(""))
    ((("j" "n" "q"))(""))
    ((("j" "n" "r"))("ȩ"))
    ((("j" "n" "s"))(""))
    ((("j" "n" "t"))(""))
    ((("j" "n" "v"))("̷"))
    ((("j" "n" "w"))(""))
    ((("j" "n" "x"))(""))
    ((("j" "n" "z"))(""))
    ((("j" "y" "a"))(""))
    ((("j" "y" "b"))(""))
    ((("j" "y" "c"))(""))
    ((("j" "y" "d"))("Ʈ"))
    ((("j" "y" "e"))(""))
    ((("j" "y" "f"))(""))
    ((("j" "y" "g"))("ʩ"))
    ((("j" "y" "q"))(""))
    ((("j" "y" "r"))("Υ"))
    ((("j" "y" "s"))(""))
    ((("j" "y" "t"))(""))
    ((("j" "y" "v"))(""))
    ((("j" "y" "w"))(""))
    ((("j" "y" "x"))(""))
    ((("j" "y" "z"))(""))
    ((("k" "h" "a"))(""))
    ((("k" "h" "b"))(""))
    ((("k" "h" "c"))(""))
    ((("k" "h" "d"))(""))
    ((("k" "h" "e"))(""))
    ((("k" "h" "f"))(""))
    ((("k" "h" "g"))(""))
    ((("k" "h" "q"))(""))
    ((("k" "h" "r"))("̩"))
    ((("k" "h" "s"))(""))
    ((("k" "h" "t"))(""))
    ((("k" "h" "v"))(""))
    ((("k" "h" "w"))(""))
    ((("k" "h" "x"))(""))
    ((("k" "h" "z"))(""))
    ((("k" "m" "a"))(""))
    ((("k" "m" "b"))(""))
    ((("k" "m" "c"))(""))
    ((("k" "m" "d"))(""))
    ((("k" "m" "e"))(""))
    ((("k" "m" "f"))(""))
    ((("k" "m" "g"))(""))
    ((("k" "m" "q"))(""))
    ((("k" "m" "r"))(""))
    ((("k" "m" "s"))(""))
    ((("k" "m" "t"))(""))
    ((("k" "m" "v"))(""))
    ((("k" "m" "w"))(""))
    ((("k" "m" "x"))(""))
    ((("k" "m" "z"))(""))
    ((("k" "n" "a"))(""))
    ((("k" "n" "b"))(""))
    ((("k" "n" "c"))(""))
    ((("k" "n" "d"))(""))
    ((("k" "n" "e"))(""))
    ((("k" "n" "f"))(""))
    ((("k" "n" "g"))("ͦ"))
    ((("k" "n" "q"))(""))
    ((("k" "n" "r"))(""))
    ((("k" "n" "s"))(""))
    ((("k" "n" "t"))(""))
    ((("k" "n" "v"))(""))
    ((("k" "n" "w"))(""))
    ((("k" "n" "x"))("ʰ"))
    ((("k" "n" "z"))(""))
    ((("k" "y" "a"))(""))
    ((("k" "y" "b"))(""))
    ((("k" "y" "c"))(""))
    ((("k" "y" "d"))("ˮ"))
    ((("k" "y" "e"))(""))
    ((("k" "y" "f"))(""))
    ((("k" "y" "g"))(""))
    ((("k" "y" "q"))(""))
    ((("k" "y" "r"))(""))
    ((("k" "y" "s"))(""))
    ((("k" "y" "t"))("ͼ"))
    ((("k" "y" "v"))(""))
    ((("k" "y" "w"))(""))
    ((("k" "y" "x"))(""))
    ((("k" "y" "z"))(""))
    ((("l" "h" "a"))(""))
    ((("l" "h" "b"))(""))
    ((("l" "h" "c"))(""))
    ((("l" "h" "d"))(""))
    ((("l" "h" "e"))(""))
    ((("l" "h" "f"))(""))
    ((("l" "h" "g"))(""))
    ((("l" "h" "q"))(""))
    ((("l" "h" "r"))(""))
    ((("l" "h" "s"))(""))
    ((("l" "h" "t"))("Ʀ"))
    ((("l" "h" "v"))(""))
    ((("l" "h" "w"))(""))
    ((("l" "h" "x"))(""))
    ((("l" "h" "z"))(""))
    ((("l" "m" "a"))("Ǣ"))
    ((("l" "m" "b"))(""))
    ((("l" "m" "c"))(""))
    ((("l" "m" "d"))(""))
    ((("l" "m" "e"))(""))
    ((("l" "m" "f"))(""))
    ((("l" "m" "g"))(""))
    ((("l" "m" "q"))(""))
    ((("l" "m" "r"))(""))
    ((("l" "m" "s"))(""))
    ((("l" "m" "t"))(""))
    ((("l" "m" "v"))(""))
    ((("l" "m" "w"))("˹"))
    ((("l" "m" "x"))(""))
    ((("l" "m" "z"))(""))
    ((("l" "n" "a"))(""))
    ((("l" "n" "b"))(""))
    ((("l" "n" "c"))(""))
    ((("l" "n" "d"))("Χ"))
    ((("l" "n" "e"))(""))
    ((("l" "n" "f"))(""))
    ((("l" "n" "g"))(""))
    ((("l" "n" "q"))(""))
    ((("l" "n" "r"))(""))
    ((("l" "n" "s"))("ͫ"))
    ((("l" "n" "t"))("ϡ"))
    ((("l" "n" "v"))(""))
    ((("l" "n" "w"))(""))
    ((("l" "n" "x"))(""))
    ((("l" "n" "z"))(""))
    ((("l" "y" "a"))(""))
    ((("l" "y" "b"))(""))
    ((("l" "y" "c"))(""))
    ((("l" "y" "d"))(""))
    ((("l" "y" "e"))("ʻ"))
    ((("l" "y" "f"))(""))
    ((("l" "y" "g"))("ð"))
    ((("l" "y" "q"))(""))
    ((("l" "y" "r"))(""))
    ((("l" "y" "s"))(""))
    ((("l" "y" "t"))(""))
    ((("l" "y" "v"))("ť"))
    ((("l" "y" "w"))(""))
    ((("l" "y" "x"))(""))
    ((("l" "y" "z"))(""))
    ((("m" "h" "a"))(""))
    ((("m" "h" "b"))(""))
    ((("m" "h" "c"))("Ρ"))
    ((("m" "h" "d"))(""))
    ((("m" "h" "e"))(""))
    ((("m" "h" "f"))("©"))
    ((("m" "h" "g"))("Ƨ"))
    ((("m" "h" "q"))(""))
    ((("m" "h" "r"))(""))
    ((("m" "h" "s"))(""))
    ((("m" "h" "t"))(""))
    ((("m" "h" "v"))(""))
    ((("m" "h" "w"))(""))
    ((("m" "h" "x"))("Ȳ"))
    ((("m" "h" "z"))(""))
    ((("m" "m" "a"))(""))
    ((("m" "m" "b"))(""))
    ((("m" "m" "c"))(""))
    ((("m" "m" "d"))(""))
    ((("m" "m" "e"))(""))
    ((("m" "m" "f"))(""))
    ((("m" "m" "g"))(""))
    ((("m" "m" "q"))(""))
    ((("m" "m" "r"))(""))
    ((("m" "m" "s"))(""))
    ((("m" "m" "t"))(""))
    ((("m" "m" "v"))(""))
    ((("m" "m" "w"))(""))
    ((("m" "m" "x"))(""))
    ((("m" "m" "z"))(""))
    ((("m" "n" "a"))(""))
    ((("m" "n" "b"))("ʵ"))
    ((("m" "n" "c"))(""))
    ((("m" "n" "d"))(""))
    ((("m" "n" "e"))(""))
    ((("m" "n" "f"))("ê"))
    ((("m" "n" "g"))(""))
    ((("m" "n" "q"))(""))
    ((("m" "n" "r"))(""))
    ((("m" "n" "s"))(""))
    ((("m" "n" "t"))(""))
    ((("m" "n" "v"))(""))
    ((("m" "n" "w"))("̰"))
    ((("m" "n" "x"))(""))
    ((("m" "n" "z"))(""))
    ((("m" "y" "a"))("϶"))
    ((("m" "y" "b"))(""))
    ((("m" "y" "c"))("ö"))
    ((("m" "y" "d"))(""))
    ((("m" "y" "e"))(""))
    ((("m" "y" "f"))(""))
    ((("m" "y" "g"))("ĺ"))
    ((("m" "y" "q"))("ķ"))
    ((("m" "y" "r"))(""))
    ((("m" "y" "s"))(""))
    ((("m" "y" "t"))(""))
    ((("m" "y" "v"))(""))
    ((("m" "y" "w"))(""))
    ((("m" "y" "x"))(""))
    ((("m" "y" "z"))(""))
    ((("n" "h" "a"))(""))
    ((("n" "h" "b"))("ʽ"))
    ((("n" "h" "c"))(""))
    ((("n" "h" "d"))(""))
    ((("n" "h" "e"))(""))
    ((("n" "h" "f"))(""))
    ((("n" "h" "g"))(""))
    ((("n" "h" "q"))(""))
    ((("n" "h" "r"))(""))
    ((("n" "h" "s"))(""))
    ((("n" "h" "t"))("¶"))
    ((("n" "h" "v"))(""))
    ((("n" "h" "w"))(""))
    ((("n" "h" "x"))(""))
    ((("n" "h" "z"))(""))
    ((("n" "m" "a"))(""))
    ((("n" "m" "b"))(""))
    ((("n" "m" "c"))(""))
    ((("n" "m" "d"))(""))
    ((("n" "m" "e"))(""))
    ((("n" "m" "f"))("̮"))
    ((("n" "m" "g"))(""))
    ((("n" "m" "q"))(""))
    ((("n" "m" "r"))(""))
    ((("n" "m" "s"))("ͯ"))
    ((("n" "m" "t"))(""))
    ((("n" "m" "v"))(""))
    ((("n" "m" "w"))(""))
    ((("n" "m" "x"))("÷"))
    ((("n" "m" "z"))(""))
    ((("n" "n" "a"))(""))
    ((("n" "n" "b"))(""))
    ((("n" "n" "c"))(""))
    ((("n" "n" "d"))(""))
    ((("n" "n" "e"))(""))
    ((("n" "n" "f"))(""))
    ((("n" "n" "g"))(""))
    ((("n" "n" "q"))(""))
    ((("n" "n" "r"))(""))
    ((("n" "n" "s"))("̨"))
    ((("n" "n" "t"))(""))
    ((("n" "n" "v"))(""))
    ((("n" "n" "w"))(""))
    ((("n" "n" "x"))("è"))
    ((("n" "n" "z"))("˲"))
    ((("n" "y" "a"))(""))
    ((("n" "y" "b"))(""))
    ((("n" "y" "c"))(""))
    ((("n" "y" "d"))(""))
    ((("n" "y" "e"))("ͱ"))
    ((("n" "y" "f"))(""))
    ((("n" "y" "g"))("±"))
    ((("n" "y" "q"))(""))
    ((("n" "y" "r"))(""))
    ((("n" "y" "s"))(""))
    ((("n" "y" "t"))(""))
    ((("n" "y" "v"))(""))
    ((("n" "y" "w"))(""))
    ((("n" "y" "x"))("ƴ"))
    ((("n" "y" "z"))(""))
    ((("o" "h" "a"))(""))
    ((("o" "h" "b"))(""))
    ((("o" "h" "c"))("¹"))
    ((("o" "h" "d"))(""))
    ((("o" "h" "e"))(""))
    ((("o" "h" "f"))("ε"))
    ((("o" "h" "g"))("̴"))
    ((("o" "h" "q"))(""))
    ((("o" "h" "r"))(""))
    ((("o" "h" "s"))(""))
    ((("o" "h" "t"))("λ"))
    ((("o" "h" "v"))(""))
    ((("o" "h" "w"))(""))
    ((("o" "h" "x"))(""))
    ((("o" "h" "z"))("Ĥ"))
    ((("o" "m" "a"))(""))
    ((("o" "m" "b"))(""))
    ((("o" "m" "c"))(""))
    ((("o" "m" "d"))(""))
    ((("o" "m" "e"))(""))
    ((("o" "m" "f"))(""))
    ((("o" "m" "g"))(""))
    ((("o" "m" "q"))(""))
    ((("o" "m" "r"))(""))
    ((("o" "m" "s"))(""))
    ((("o" "m" "t"))(""))
    ((("o" "m" "v"))(""))
    ((("o" "m" "w"))(""))
    ((("o" "m" "x"))("ϼ"))
    ((("o" "m" "z"))("ɪ"))
    ((("o" "n" "a"))(""))
    ((("o" "n" "b"))(""))
    ((("o" "n" "c"))("ţ"))
    ((("o" "n" "d"))(""))
    ((("o" "n" "e"))("ˢ"))
    ((("o" "n" "f"))(""))
    ((("o" "n" "g"))(""))
    ((("o" "n" "q"))(""))
    ((("o" "n" "r"))(""))
    ((("o" "n" "s"))(""))
    ((("o" "n" "t"))(""))
    ((("o" "n" "v"))(""))
    ((("o" "n" "w"))(""))
    ((("o" "n" "x"))(""))
    ((("o" "n" "z"))(""))
    ((("o" "y" "a"))(""))
    ((("o" "y" "b"))(""))
    ((("o" "y" "c"))("ɡ"))
    ((("o" "y" "d"))("ɼ"))
    ((("o" "y" "e"))(""))
    ((("o" "y" "f"))(""))
    ((("o" "y" "g"))(""))
    ((("o" "y" "q"))(""))
    ((("o" "y" "r"))(""))
    ((("o" "y" "s"))(""))
    ((("o" "y" "t"))(""))
    ((("o" "y" "v"))(""))
    ((("o" "y" "w"))(""))
    ((("o" "y" "x"))(""))
    ((("o" "y" "z"))(""))
    ((("p" "h" "a"))(""))
    ((("p" "h" "b"))(""))
    ((("p" "h" "c"))(""))
    ((("p" "h" "d"))(""))
    ((("p" "h" "e"))(""))
    ((("p" "h" "f"))(""))
    ((("p" "h" "g"))("ʣ"))
    ((("p" "h" "q"))(""))
    ((("p" "h" "r"))(""))
    ((("p" "h" "s"))(""))
    ((("p" "h" "t"))("͵"))
    ((("p" "h" "v"))("˸"))
    ((("p" "h" "w"))("¥"))
    ((("p" "h" "x"))("ʾ"))
    ((("p" "h" "z"))(""))
    ((("p" "m" "a"))(""))
    ((("p" "m" "b"))(""))
    ((("p" "m" "c"))(""))
    ((("p" "m" "d"))(""))
    ((("p" "m" "e"))(""))
    ((("p" "m" "f"))(""))
    ((("p" "m" "g"))(""))
    ((("p" "m" "q"))(""))
    ((("p" "m" "r"))(""))
    ((("p" "m" "s"))(""))
    ((("p" "m" "t"))(""))
    ((("p" "m" "v"))(""))
    ((("p" "m" "w"))(""))
    ((("p" "m" "x"))(""))
    ((("p" "m" "z"))(""))
    ((("p" "n" "a"))(""))
    ((("p" "n" "b"))("ɨ"))
    ((("p" "n" "c"))("î"))
    ((("p" "n" "d"))(""))
    ((("p" "n" "e"))(""))
    ((("p" "n" "f"))(""))
    ((("p" "n" "g"))("˶"))
    ((("p" "n" "q"))(""))
    ((("p" "n" "r"))(""))
    ((("p" "n" "s"))(""))
    ((("p" "n" "t"))(""))
    ((("p" "n" "v"))(""))
    ((("p" "n" "w"))(""))
    ((("p" "n" "x"))(""))
    ((("p" "n" "z"))(""))
    ((("p" "y" "a"))(""))
    ((("p" "y" "b"))(""))
    ((("p" "y" "c"))("â"))
    ((("p" "y" "d"))(""))
    ((("p" "y" "e"))("Ķ"))
    ((("p" "y" "f"))(""))
    ((("p" "y" "g"))("«"))
    ((("p" "y" "q"))("˵"))
    ((("p" "y" "r"))(""))
    ((("p" "y" "s"))(""))
    ((("p" "y" "t"))(""))
    ((("p" "y" "v"))(""))
    ((("p" "y" "w"))(""))
    ((("p" "y" "x"))(""))
    ((("p" "y" "z"))(""))
    ((("q" "b" ","))(""))
    ((("q" "b" "."))("þ"))
    ((("q" "b" "/"))("Ϯ"))
    ((("q" "b" ";"))(""))
    ((("q" "b" "h"))(""))
    ((("q" "b" "i"))(""))
    ((("q" "b" "j"))(""))
    ((("q" "b" "k"))(""))
    ((("q" "b" "l"))(""))
    ((("q" "b" "m"))("ɵ"))
    ((("q" "b" "n"))(""))
    ((("q" "b" "o"))(""))
    ((("q" "b" "p"))(""))
    ((("q" "b" "u"))(""))
    ((("q" "b" "y"))(""))
    ((("q" "g" ","))(""))
    ((("q" "g" "."))(""))
    ((("q" "g" "/"))("Ȼ"))
    ((("q" "g" ";"))(""))
    ((("q" "g" "h"))(""))
    ((("q" "g" "i"))(""))
    ((("q" "g" "j"))(""))
    ((("q" "g" "k"))(""))
    ((("q" "g" "l"))(""))
    ((("q" "g" "m"))(""))
    ((("q" "g" "n"))(""))
    ((("q" "g" "o"))("Ͷ"))
    ((("q" "g" "p"))(""))
    ((("q" "g" "u"))(""))
    ((("q" "g" "y"))("ů"))
    ((("q" "t" ","))(""))
    ((("q" "t" "."))("˰"))
    ((("q" "t" "/"))(""))
    ((("q" "t" ";"))(""))
    ((("q" "t" "h"))(""))
    ((("q" "t" "i"))("̥"))
    ((("q" "t" "j"))(""))
    ((("q" "t" "k"))(""))
    ((("q" "t" "l"))(""))
    ((("q" "t" "m"))(""))
    ((("q" "t" "n"))(""))
    ((("q" "t" "o"))(""))
    ((("q" "t" "p"))("ò"))
    ((("q" "t" "u"))("˺"))
    ((("q" "t" "y"))(""))
    ((("q" "v" ","))(""))
    ((("q" "v" "."))(""))
    ((("q" "v" "/"))(""))
    ((("q" "v" ";"))(""))
    ((("q" "v" "h"))(""))
    ((("q" "v" "i"))(""))
    ((("q" "v" "j"))("ʷ"))
    ((("q" "v" "k"))("˦"))
    ((("q" "v" "l"))(""))
    ((("q" "v" "m"))(""))
    ((("q" "v" "n"))("Ͼ"))
    ((("q" "v" "o"))(""))
    ((("q" "v" "p"))(""))
    ((("q" "v" "u"))(""))
    ((("q" "v" "y"))(""))
    ((("r" "b" ","))(""))
    ((("r" "b" "."))("μ"))
    ((("r" "b" "/"))(""))
    ((("r" "b" ";"))(""))
    ((("r" "b" "h"))(""))
    ((("r" "b" "i"))(""))
    ((("r" "b" "j"))(""))
    ((("r" "b" "k"))("¡"))
    ((("r" "b" "l"))(""))
    ((("r" "b" "m"))(""))
    ((("r" "b" "n"))("Ī"))
    ((("r" "b" "o"))(""))
    ((("r" "b" "p"))(""))
    ((("r" "b" "u"))(""))
    ((("r" "b" "y"))(""))
    ((("r" "g" ","))("£"))
    ((("r" "g" "."))(""))
    ((("r" "g" "/"))("ȳ"))
    ((("r" "g" ";"))(""))
    ((("r" "g" "h"))(""))
    ((("r" "g" "i"))(""))
    ((("r" "g" "j"))(""))
    ((("r" "g" "k"))(""))
    ((("r" "g" "l"))(""))
    ((("r" "g" "m"))(""))
    ((("r" "g" "n"))(""))
    ((("r" "g" "o"))(""))
    ((("r" "g" "p"))(""))
    ((("r" "g" "u"))(""))
    ((("r" "g" "y"))(""))
    ((("r" "t" ","))(""))
    ((("r" "t" "."))(""))
    ((("r" "t" "/"))(""))
    ((("r" "t" ";"))(""))
    ((("r" "t" "h"))(""))
    ((("r" "t" "i"))("¬"))
    ((("r" "t" "j"))(""))
    ((("r" "t" "k"))(""))
    ((("r" "t" "l"))(""))
    ((("r" "t" "m"))(""))
    ((("r" "t" "n"))(""))
    ((("r" "t" "o"))(""))
    ((("r" "t" "p"))(""))
    ((("r" "t" "u"))(""))
    ((("r" "t" "y"))(""))
    ((("r" "v" ","))(""))
    ((("r" "v" "."))(""))
    ((("r" "v" "/"))(""))
    ((("r" "v" ";"))(""))
    ((("r" "v" "h"))(""))
    ((("r" "v" "i"))(""))
    ((("r" "v" "j"))(""))
    ((("r" "v" "k"))(""))
    ((("r" "v" "l"))(""))
    ((("r" "v" "m"))(""))
    ((("r" "v" "n"))(""))
    ((("r" "v" "o"))(""))
    ((("r" "v" "p"))(""))
    ((("r" "v" "u"))(""))
    ((("r" "v" "y"))(""))
    ((("s" "b" ","))(""))
    ((("s" "b" "."))(""))
    ((("s" "b" "/"))(""))
    ((("s" "b" ";"))(""))
    ((("s" "b" "h"))(""))
    ((("s" "b" "i"))(""))
    ((("s" "b" "j"))(""))
    ((("s" "b" "k"))(""))
    ((("s" "b" "l"))(""))
    ((("s" "b" "m"))(""))
    ((("s" "b" "n"))(""))
    ((("s" "b" "o"))(""))
    ((("s" "b" "p"))(""))
    ((("s" "b" "u"))(""))
    ((("s" "b" "y"))("ǭ"))
    ((("s" "g" ","))("Ϫ"))
    ((("s" "g" "."))(""))
    ((("s" "g" "/"))(""))
    ((("s" "g" ";"))(""))
    ((("s" "g" "h"))(""))
    ((("s" "g" "i"))(""))
    ((("s" "g" "j"))(""))
    ((("s" "g" "k"))(""))
    ((("s" "g" "l"))(""))
    ((("s" "g" "m"))(""))
    ((("s" "g" "n"))(""))
    ((("s" "g" "o"))(""))
    ((("s" "g" "p"))(""))
    ((("s" "g" "u"))(""))
    ((("s" "g" "y"))(""))
    ((("s" "t" ","))(""))
    ((("s" "t" "."))(""))
    ((("s" "t" "/"))(""))
    ((("s" "t" ";"))(""))
    ((("s" "t" "h"))(""))
    ((("s" "t" "i"))(""))
    ((("s" "t" "j"))(""))
    ((("s" "t" "k"))(""))
    ((("s" "t" "l"))(""))
    ((("s" "t" "m"))(""))
    ((("s" "t" "n"))(""))
    ((("s" "t" "o"))(""))
    ((("s" "t" "p"))(""))
    ((("s" "t" "u"))(""))
    ((("s" "t" "y"))("õ"))
    ((("s" "v" ","))(""))
    ((("s" "v" "."))(""))
    ((("s" "v" "/"))(""))
    ((("s" "v" ";"))("ɶ"))
    ((("s" "v" "h"))(""))
    ((("s" "v" "i"))(""))
    ((("s" "v" "j"))(""))
    ((("s" "v" "k"))(""))
    ((("s" "v" "l"))(""))
    ((("s" "v" "m"))(""))
    ((("s" "v" "n"))("ϳ"))
    ((("s" "v" "o"))(""))
    ((("s" "v" "p"))(""))
    ((("s" "v" "u"))(""))
    ((("s" "v" "y"))(""))
    ((("t" "b" ","))(""))
    ((("t" "b" "."))(""))
    ((("t" "b" "/"))(""))
    ((("t" "b" ";"))(""))
    ((("t" "b" "h"))(""))
    ((("t" "b" "i"))("Ȧ"))
    ((("t" "b" "j"))("˳"))
    ((("t" "b" "k"))(""))
    ((("t" "b" "l"))(""))
    ((("t" "b" "m"))(""))
    ((("t" "b" "n"))("̽"))
    ((("t" "b" "o"))(""))
    ((("t" "b" "p"))(""))
    ((("t" "b" "u"))(""))
    ((("t" "b" "y"))(""))
    ((("t" "g" ","))(""))
    ((("t" "g" "."))(""))
    ((("t" "g" "/"))(""))
    ((("t" "g" ";"))(""))
    ((("t" "g" "h"))(""))
    ((("t" "g" "i"))(""))
    ((("t" "g" "j"))(""))
    ((("t" "g" "k"))(""))
    ((("t" "g" "l"))(""))
    ((("t" "g" "m"))(""))
    ((("t" "g" "n"))(""))
    ((("t" "g" "o"))(""))
    ((("t" "g" "p"))(""))
    ((("t" "g" "u"))(""))
    ((("t" "g" "y"))(""))
    ((("t" "t" ","))(""))
    ((("t" "t" "."))(""))
    ((("t" "t" "/"))(""))
    ((("t" "t" ";"))(""))
    ((("t" "t" "h"))(""))
    ((("t" "t" "i"))("ϯ"))
    ((("t" "t" "j"))("α"))
    ((("t" "t" "k"))(""))
    ((("t" "t" "l"))("ȼ"))
    ((("t" "t" "m"))("ū"))
    ((("t" "t" "n"))(""))
    ((("t" "t" "o"))(""))
    ((("t" "t" "p"))(""))
    ((("t" "t" "u"))(""))
    ((("t" "t" "y"))(""))
    ((("t" "v" ","))(""))
    ((("t" "v" "."))(""))
    ((("t" "v" "/"))(""))
    ((("t" "v" ";"))(""))
    ((("t" "v" "h"))(""))
    ((("t" "v" "i"))(""))
    ((("t" "v" "j"))(""))
    ((("t" "v" "k"))("˥"))
    ((("t" "v" "l"))(""))
    ((("t" "v" "m"))(""))
    ((("t" "v" "n"))("ı"))
    ((("t" "v" "o"))(""))
    ((("t" "v" "p"))(""))
    ((("t" "v" "u"))(""))
    ((("t" "v" "y"))(""))
    ((("u" "h" "a"))(""))
    ((("u" "h" "b"))(""))
    ((("u" "h" "c"))(""))
    ((("u" "h" "d"))(""))
    ((("u" "h" "e"))(""))
    ((("u" "h" "f"))(""))
    ((("u" "h" "g"))(""))
    ((("u" "h" "q"))(""))
    ((("u" "h" "r"))("ɸ"))
    ((("u" "h" "s"))(""))
    ((("u" "h" "t"))(""))
    ((("u" "h" "v"))("Ĭ"))
    ((("u" "h" "w"))(""))
    ((("u" "h" "x"))(""))
    ((("u" "h" "z"))(""))
    ((("u" "m" "a"))(""))
    ((("u" "m" "b"))(""))
    ((("u" "m" "c"))(""))
    ((("u" "m" "d"))("˻"))
    ((("u" "m" "e"))(""))
    ((("u" "m" "f"))(""))
    ((("u" "m" "g"))(""))
    ((("u" "m" "q"))(""))
    ((("u" "m" "r"))(""))
    ((("u" "m" "s"))("ǥ"))
    ((("u" "m" "t"))(""))
    ((("u" "m" "v"))(""))
    ((("u" "m" "w"))(""))
    ((("u" "m" "x"))("˱"))
    ((("u" "m" "z"))(""))
    ((("u" "n" "a"))(""))
    ((("u" "n" "b"))(""))
    ((("u" "n" "c"))(""))
    ((("u" "n" "d"))(""))
    ((("u" "n" "e"))(""))
    ((("u" "n" "f"))(""))
    ((("u" "n" "g"))(""))
    ((("u" "n" "q"))(""))
    ((("u" "n" "r"))("ƭ"))
    ((("u" "n" "s"))(""))
    ((("u" "n" "t"))(""))
    ((("u" "n" "v"))(""))
    ((("u" "n" "w"))(""))
    ((("u" "n" "x"))(""))
    ((("u" "n" "z"))(""))
    ((("u" "y" "a"))(""))
    ((("u" "y" "b"))(""))
    ((("u" "y" "c"))(""))
    ((("u" "y" "d"))(""))
    ((("u" "y" "e"))(""))
    ((("u" "y" "f"))(""))
    ((("u" "y" "g"))("®"))
    ((("u" "y" "q"))(""))
    ((("u" "y" "r"))(""))
    ((("u" "y" "s"))("˽"))
    ((("u" "y" "t"))(""))
    ((("u" "y" "v"))(""))
    ((("u" "y" "w"))(""))
    ((("u" "y" "x"))("ɱ"))
    ((("u" "y" "z"))(""))
    ((("v" "b" ","))("ϴ"))
    ((("v" "b" "."))(""))
    ((("v" "b" "/"))(""))
    ((("v" "b" ";"))(""))
    ((("v" "b" "h"))(""))
    ((("v" "b" "i"))(""))
    ((("v" "b" "j"))(""))
    ((("v" "b" "k"))(""))
    ((("v" "b" "l"))(""))
    ((("v" "b" "m"))(""))
    ((("v" "b" "n"))(""))
    ((("v" "b" "o"))(""))
    ((("v" "b" "p"))(""))
    ((("v" "b" "u"))(""))
    ((("v" "b" "y"))(""))
    ((("v" "g" ","))(""))
    ((("v" "g" "."))(""))
    ((("v" "g" "/"))("ʹ"))
    ((("v" "g" ";"))(""))
    ((("v" "g" "h"))("Ģ"))
    ((("v" "g" "i"))(""))
    ((("v" "g" "j"))(""))
    ((("v" "g" "k"))(""))
    ((("v" "g" "l"))(""))
    ((("v" "g" "m"))(""))
    ((("v" "g" "n"))(""))
    ((("v" "g" "o"))(""))
    ((("v" "g" "p"))(""))
    ((("v" "g" "u"))(""))
    ((("v" "g" "y"))(""))
    ((("v" "t" ","))(""))
    ((("v" "t" "."))(""))
    ((("v" "t" "/"))(""))
    ((("v" "t" ";"))(""))
    ((("v" "t" "h"))(""))
    ((("v" "t" "i"))(""))
    ((("v" "t" "j"))(""))
    ((("v" "t" "k"))(""))
    ((("v" "t" "l"))(""))
    ((("v" "t" "m"))(""))
    ((("v" "t" "n"))("Ŀ"))
    ((("v" "t" "o"))("ϣ"))
    ((("v" "t" "p"))(""))
    ((("v" "t" "u"))(""))
    ((("v" "t" "y"))(""))
    ((("v" "v" ","))(""))
    ((("v" "v" "."))(""))
    ((("v" "v" "/"))(""))
    ((("v" "v" ";"))(""))
    ((("v" "v" "h"))(""))
    ((("v" "v" "i"))(""))
    ((("v" "v" "j"))(""))
    ((("v" "v" "k"))(""))
    ((("v" "v" "l"))(""))
    ((("v" "v" "m"))(""))
    ((("v" "v" "n"))(""))
    ((("v" "v" "o"))(""))
    ((("v" "v" "p"))(""))
    ((("v" "v" "u"))(""))
    ((("v" "v" "y"))(""))
    ((("w" "b" ","))(""))
    ((("w" "b" "."))(""))
    ((("w" "b" "/"))(""))
    ((("w" "b" ";"))(""))
    ((("w" "b" "h"))("˿"))
    ((("w" "b" "i"))("ũ"))
    ((("w" "b" "j"))(""))
    ((("w" "b" "k"))(""))
    ((("w" "b" "l"))(""))
    ((("w" "b" "m"))(""))
    ((("w" "b" "n"))("á"))
    ((("w" "b" "o"))(""))
    ((("w" "b" "p"))(""))
    ((("w" "b" "u"))(""))
    ((("w" "b" "y"))(""))
    ((("w" "g" ","))(""))
    ((("w" "g" "."))(""))
    ((("w" "g" "/"))(""))
    ((("w" "g" ";"))(""))
    ((("w" "g" "h"))(""))
    ((("w" "g" "i"))(""))
    ((("w" "g" "j"))(""))
    ((("w" "g" "k"))(""))
    ((("w" "g" "l"))(""))
    ((("w" "g" "m"))("ϭ"))
    ((("w" "g" "n"))(""))
    ((("w" "g" "o"))(""))
    ((("w" "g" "p"))("ʥ"))
    ((("w" "g" "u"))(""))
    ((("w" "g" "y"))(""))
    ((("w" "t" ","))(""))
    ((("w" "t" "."))("ϰ"))
    ((("w" "t" "/"))(""))
    ((("w" "t" ";"))(""))
    ((("w" "t" "h"))(""))
    ((("w" "t" "i"))(""))
    ((("w" "t" "j"))(""))
    ((("w" "t" "k"))(""))
    ((("w" "t" "l"))(""))
    ((("w" "t" "m"))("·"))
    ((("w" "t" "n"))(""))
    ((("w" "t" "o"))("»"))
    ((("w" "t" "p"))(""))
    ((("w" "t" "u"))(""))
    ((("w" "t" "y"))(""))
    ((("w" "v" ","))("Ǩ"))
    ((("w" "v" "."))(""))
    ((("w" "v" "/"))(""))
    ((("w" "v" ";"))("ͩ"))
    ((("w" "v" "h"))(""))
    ((("w" "v" "i"))(""))
    ((("w" "v" "j"))(""))
    ((("w" "v" "k"))(""))
    ((("w" "v" "l"))(""))
    ((("w" "v" "m"))(""))
    ((("w" "v" "n"))(""))
    ((("w" "v" "o"))("ƿ"))
    ((("w" "v" "p"))(""))
    ((("w" "v" "u"))("ɺ"))
    ((("w" "v" "y"))(""))
    ((("x" "b" ","))(""))
    ((("x" "b" "."))(""))
    ((("x" "b" "/"))(""))
    ((("x" "b" ";"))(""))
    ((("x" "b" "h"))(""))
    ((("x" "b" "i"))(""))
    ((("x" "b" "j"))(""))
    ((("x" "b" "k"))(""))
    ((("x" "b" "l"))(""))
    ((("x" "b" "m"))("˩"))
    ((("x" "b" "n"))(""))
    ((("x" "b" "o"))(""))
    ((("x" "b" "p"))(""))
    ((("x" "b" "u"))(""))
    ((("x" "b" "y"))(""))
    ((("x" "g" ","))(""))
    ((("x" "g" "."))(""))
    ((("x" "g" "/"))(""))
    ((("x" "g" ";"))(""))
    ((("x" "g" "h"))(""))
    ((("x" "g" "i"))(""))
    ((("x" "g" "j"))(""))
    ((("x" "g" "k"))("˷"))
    ((("x" "g" "l"))(""))
    ((("x" "g" "m"))(""))
    ((("x" "g" "n"))(""))
    ((("x" "g" "o"))(""))
    ((("x" "g" "p"))("ǫ"))
    ((("x" "g" "u"))(""))
    ((("x" "g" "y"))(""))
    ((("x" "t" ","))(""))
    ((("x" "t" "."))(""))
    ((("x" "t" "/"))(""))
    ((("x" "t" ";"))(""))
    ((("x" "t" "h"))(""))
    ((("x" "t" "i"))(""))
    ((("x" "t" "j"))(""))
    ((("x" "t" "k"))(""))
    ((("x" "t" "l"))(""))
    ((("x" "t" "m"))(""))
    ((("x" "t" "n"))(""))
    ((("x" "t" "o"))(""))
    ((("x" "t" "p"))(""))
    ((("x" "t" "u"))(""))
    ((("x" "t" "y"))(""))
    ((("x" "v" ","))(""))
    ((("x" "v" "."))(""))
    ((("x" "v" "/"))(""))
    ((("x" "v" ";"))(""))
    ((("x" "v" "h"))(""))
    ((("x" "v" "i"))(""))
    ((("x" "v" "j"))(""))
    ((("x" "v" "k"))(""))
    ((("x" "v" "l"))(""))
    ((("x" "v" "m"))(""))
    ((("x" "v" "n"))(""))
    ((("x" "v" "o"))(""))
    ((("x" "v" "p"))("Ȥ"))
    ((("x" "v" "u"))(""))
    ((("x" "v" "y"))(""))
    ((("y" "h" "a"))(""))
    ((("y" "h" "b"))("ϧ"))
    ((("y" "h" "c"))(""))
    ((("y" "h" "d"))(""))
    ((("y" "h" "e"))(""))
    ((("y" "h" "f"))(""))
    ((("y" "h" "g"))("Ϸ"))
    ((("y" "h" "q"))("ȡ"))
    ((("y" "h" "r"))(""))
    ((("y" "h" "s"))("θ"))
    ((("y" "h" "t"))(""))
    ((("y" "h" "v"))(""))
    ((("y" "h" "w"))(""))
    ((("y" "h" "x"))(""))
    ((("y" "h" "z"))(""))
    ((("y" "m" "a"))(""))
    ((("y" "m" "b"))(""))
    ((("y" "m" "c"))(""))
    ((("y" "m" "d"))(""))
    ((("y" "m" "e"))(""))
    ((("y" "m" "f"))(""))
    ((("y" "m" "g"))(""))
    ((("y" "m" "q"))(""))
    ((("y" "m" "r"))(""))
    ((("y" "m" "s"))("¯"))
    ((("y" "m" "t"))(""))
    ((("y" "m" "v"))(""))
    ((("y" "m" "w"))(""))
    ((("y" "m" "x"))(""))
    ((("y" "m" "z"))(""))
    ((("y" "n" "a"))(""))
    ((("y" "n" "b"))(""))
    ((("y" "n" "c"))(""))
    ((("y" "n" "d"))(""))
    ((("y" "n" "e"))(""))
    ((("y" "n" "f"))(""))
    ((("y" "n" "g"))(""))
    ((("y" "n" "q"))(""))
    ((("y" "n" "r"))(""))
    ((("y" "n" "s"))("̻"))
    ((("y" "n" "t"))(""))
    ((("y" "n" "v"))(""))
    ((("y" "n" "w"))(""))
    ((("y" "n" "x"))(""))
    ((("y" "n" "z"))(""))
    ((("y" "y" "a"))(""))
    ((("y" "y" "b"))(""))
    ((("y" "y" "c"))(""))
    ((("y" "y" "d"))(""))
    ((("y" "y" "e"))(""))
    ((("y" "y" "f"))(""))
    ((("y" "y" "g"))(""))
    ((("y" "y" "q"))(""))
    ((("y" "y" "r"))(""))
    ((("y" "y" "s"))("ƫ"))
    ((("y" "y" "t"))(""))
    ((("y" "y" "v"))(""))
    ((("y" "y" "w"))("ɹ"))
    ((("y" "y" "x"))(""))
    ((("y" "y" "z"))(""))
    ((("z" "b" ","))(""))
    ((("z" "b" "."))(""))
    ((("z" "b" "/"))(""))
    ((("z" "b" ";"))(""))
    ((("z" "b" "h"))(""))
    ((("z" "b" "i"))(""))
    ((("z" "b" "j"))(""))
    ((("z" "b" "k"))(""))
    ((("z" "b" "l"))(""))
    ((("z" "b" "m"))(""))
    ((("z" "b" "n"))(""))
    ((("z" "b" "o"))(""))
    ((("z" "b" "p"))(""))
    ((("z" "b" "u"))(""))
    ((("z" "b" "y"))(""))
    ((("z" "g" ","))(""))
    ((("z" "g" "."))(""))
    ((("z" "g" "/"))(""))
    ((("z" "g" ";"))(""))
    ((("z" "g" "h"))(""))
    ((("z" "g" "i"))(""))
    ((("z" "g" "j"))(""))
    ((("z" "g" "k"))(""))
    ((("z" "g" "l"))(""))
    ((("z" "g" "m"))("ͤ"))
    ((("z" "g" "n"))(""))
    ((("z" "g" "o"))(""))
    ((("z" "g" "p"))(""))
    ((("z" "g" "u"))(""))
    ((("z" "g" "y"))(""))
    ((("z" "t" ","))(""))
    ((("z" "t" "."))(""))
    ((("z" "t" "/"))(""))
    ((("z" "t" ";"))(""))
    ((("z" "t" "h"))("ļ"))
    ((("z" "t" "i"))(""))
    ((("z" "t" "j"))(""))
    ((("z" "t" "k"))(""))
    ((("z" "t" "l"))("Ǵ"))
    ((("z" "t" "m"))(""))
    ((("z" "t" "n"))(""))
    ((("z" "t" "o"))(""))
    ((("z" "t" "p"))(""))
    ((("z" "t" "u"))(""))
    ((("z" "t" "y"))(""))
    ((("z" "v" ","))(""))
    ((("z" "v" "."))(""))
    ((("z" "v" "/"))(""))
    ((("z" "v" ";"))(""))
    ((("z" "v" "h"))(""))
    ((("z" "v" "i"))(""))
    ((("z" "v" "j"))("̭"))
    ((("z" "v" "k"))(""))
    ((("z" "v" "l"))(""))
    ((("z" "v" "m"))(""))
    ((("z" "v" "n"))(""))
    ((("z" "v" "o"))("ɦ"))
    ((("z" "v" "p"))(""))
    ((("z" "v" "u"))(""))
    ((("z" "v" "y"))(""))))

;;; ѴбΤɲ52ʸȡ
;;; ʹ񡢶Ʊ̿īʹNHKʤɤȼ˻Ѥ᤿
;;; бΤɲ11ʸ־ʱ
;;; http://www.geocities.jp/ken1noguchi/TUT-CODE/kankyo/download.htm
(define tutcode-rule-shin-joyo-kanji-plus
  '(
    ((("d" "g" "g"))(""))
    ((("p" "h" "h"))(""))
    ((("q" "t" "t"))(""))
    ((("j" "n" "n"))(""))
    ((("k" "h" "h"))(""))
    ((("f" "g" "g"))(""))
    ((("q" "g" "g"))(""))
    ((("." "h" "h"))("½"))
    ((("e" "v" "v"))(""))
    ((("e" "g" "g"))("ݵ"))
    ((("j" "h" "h"))(""))
    ((("c" "g" "g"))(""))
    ((("i" "m" "m"))(""))
    ((("i" "h" "h"))("ª"))
    ((("," "h" "h"))(""))
    ((("s" "b" "b"))("Ϩ"))
    ((("a" "b" "b"))("Ľ"))
    ((("l" "h" "h"))(""))
    (((";" "h" "h"))(""))
    ((("f" "t" "t"))("Ǳ"))
    ((("," "y" "y"))(""))
    ((("/" "y" "y"))(""))
    (((";" "n" "n"))(""))
    ((("s" "g" "g"))(""))
    ((("l" "y" "y"))("Ч"))
    ((("j" "y" "y"))(""))
    ((("/" "h" "h"))(""))
    ((("o" "n" "n"))("Ŷ"))
    ((("d" "t" "t"))(""))
    ((("s" "t" "t"))("η"))
    ((("a" "t" "t"))(""))
    ((("z" "g" "g"))(""))
    ((("e" "b" "b"))(""))
    ((("w" "b" "b"))("ܴ"))
    ((("k" "y" "y"))(""))
    ((("r" "g" "g"))(""))
    (((";" "y" "y"))(""))
    ((("." "y" "y"))(""))
    ((("i" "n" "n"))("ɲ"))
    ((("f" "v" "v"))(""))
    ((("e" "t" "t"))(""))
    ((("u" "h" "h"))(""))
    ((("x" "t" "t"))(""))
    ((("l" "m" "m"))(""))
    ((("i" "y" "y"))(""))
    ((("o" "y" "y"))(""))
    ((("u" "y" "y"))(""))
    ((("s" "v" "v"))("Ӯ"))
    ((("o" "h" "h"))("ۣ"))
    ((("p" "y" "y"))(""))
    ((("k" "n" "n"))(""))
    ((("f" "b" "b"))(""))

    ((("l" "n" "n"))(""))
    ((("d" "v" "v"))(""))
    ((("d" "b" "b"))(""))
    ((("r" "t" "t"))(""))
    ((("a" "g" "g"))(""))
    ((("w" "g" "g"))(""))
    ((("z" "t" "t"))(""))
    ((("c" "t" "t"))(""))
    ((("w" "t" "t"))(""))
    ((("k" "m" "m"))("ʱ"))
    ((("x" "g" "g"))(""))))

(if (and (symbol-bound? 'tutcode-rule-use-tutplus?)
         tutcode-rule-use-tutplus?)
  (set! tutcode-rule (append tutcode-rule tutcode-rule-shin-joyo-kanji-plus)))

(define tutcode-rule-uppercase-for-katakana
  '(
    ((("R" "K"))("" ""))
    ((("R" "I"))("" ""))
    ((("R" "U"))("" ""))
    ((("R" "H"))("" ""))
    ((("R" "J"))("" ""))
    ((("E" "K"))("" ""))
    ((("E" "I"))("" ""))
    ((("E" "U"))("" ""))
    ((("E" "H"))("" ""))
    ((("E" "J"))("" ""))
    ((("S" "K"))("" ""))
    ((("S" "I"))("" ""))
    ((("S" "U"))("" ""))
    ((("S" "H"))("" ""))
    ((("S" "J"))("" ""))
    ((("D" "K"))("" ""))
    ((("D" "I"))("" ""))
    ((("D" "U"))("" ""))
    ((("D" "H"))("" ""))
    ((("D" "J"))("" ""))
    ((("F" "K"))("" ""))
    ((("F" "I"))("" ""))
    ((("F" "U"))("" ""))
    ((("F" "H"))("" ""))
    ((("F" "J"))("" ""))
    ((("T" "K"))("" ""))
    ((("T" "I"))("" ""))
    ((("T" "U"))("" ""))
    ((("T" "H"))("" ""))
    ((("T" "J"))("" ""))
    ((("W" "K"))("" ""))
    ((("W" "I"))("" ""))
    ((("W" "U"))("" ""))
    ((("W" "H"))("" ""))
    ((("W" "J"))("" ""))
    ((("Q" "K"))("" ""))
    ((("Q" "U"))("" ""))
    ((("Q" "J"))("" ""))
    ((("G" "K"))("" ""))
    ((("G" "I"))("" ""))
    ((("G" "U"))("" ""))
    ((("G" "H"))("" ""))
    ((("G" "J"))("" ""))
    ((("A" "K"))("" ""))
    ((("A" "I"))("" ""))
    ((("A" "H"))("" ""))
    ((("A" "J"))("" ""))
    ((("R" "L" "K"))("" ""))
    ((("R" "L" "I"))("" ""))
    ((("R" "L" "U"))("" ""))
    ((("R" "L" "R" "U"))(""))
    ((("R" "L" "H"))("" ""))
    ((("R" "L" "J"))("" ""))
    ((("E" "L" "K"))("" ""))
    ((("E" "L" "E" "K"))(""))
    ((("E" "L" "I"))("" ""))
    ((("E" "L" "U"))("" ""))
    ((("E" "L" "H"))("" ""))
    ((("E" "L" "E" "H"))(""))
    ((("E" "L" "J"))("" ""))
    ((("S" "L" "K"))("" ""))
    ((("S" "L" "I"))("" ""))
    ((("S" "L" "U"))("" ""))
    ((("S" "L" "H"))("" ""))
    ((("S" "L" "J"))("" ""))
    ((("D" "L" "K"))("" ""))
    ((("D" "L" "I"))("" ""))
    ((("D" "L" "U"))("" ""))
    ((("D" "L" "D" "U"))("" ""))
    ((("D" "L" "H"))("" ""))
    ((("D" "L" "J"))("" ""))
    ((("F" "L"))("" ""))
    ((("T" "L" "K"))("" ""))
    ((("T" "L" "I"))("" ""))
    ((("T" "L" "U"))("" ""))
    ((("T" "L" "H"))("" ""))
    ((("T" "L" "J"))("" ""))
    ((("T" "L" "T" "K"))("" ""))
    ((("T" "L" "T" "I"))("" ""))
    ((("T" "L" "T" "U"))("" ""))
    ((("T" "L" "T" "H"))("" ""))
    ((("T" "L" "T" "J"))("" ""))
    ((("Q" "L" "K"))("" ""))
    ((("Q" "L" "U"))("" ""))
    ((("Q" "L" "J"))("" ""))
    ((("A" "L" "K"))("" ""))))

;;; ʸǡߤΤҤ餬/ʥ⡼ɤȿФΥ/Ҥ餬ʤϤ
;;; ˤϡ~/.uim˰ʲΤ褦˵Ҥ롣
;;;   (define tutcode-rule-uppercase-as-opposite-kana? #t)
;;; (褫ưϡʸǤɬ)
(if (or (not (symbol-bound? 'tutcode-rule-uppercase-as-opposite-kana?))
        (not tutcode-rule-uppercase-as-opposite-kana?))
  (set! tutcode-rule-uppercase-for-katakana
    (map
      (lambda (x)
        (list (car x) (list (caadr x))))
      tutcode-rule-uppercase-for-katakana)))

(define tutcode-rule-uppercase-for-kigou-in-katakana
  '(
    ((("E" " "))(""))
    ((("O" " "))(""))))

;;; ʸǥϤԤϿʤ褦ˤˤϡ
;;; ~/.uim˰ʲΤ褦˵Ҥ롣(ʸǤΥϤȤʤ硢
;;; stroke-helpβ۸פǲȾʬΥեȥΰ̵ȾʬΥ
;;; ɽʤ)
;;;   (define tutcode-rule-exclude-uppercase-for-katakana? #t)
;;; ޤ˽и뤳Ȥ¿""""ʸϤΤߤ
;;; Ͽʤ褦ˤˤϡ~/.uim˰ʲΤ褦˵Ҥ롣
;;;   (define tutcode-rule-exclude-uppercase-for-kigou-in-katakana? #t)
;;; (XXX:ϡʸ((("E" " "))(""))ȤƤ⡢
;;;  ϥѴȾʸ롣򤷤ѡ
;;;  :"CODE "Ǹ"COD"ɽϥѴ"CODe ")
(if (or (not (symbol-bound? 'tutcode-rule-exclude-uppercase-for-katakana?))
        (not tutcode-rule-exclude-uppercase-for-katakana?))
  (set! tutcode-rule
    (append
      tutcode-rule
      tutcode-rule-uppercase-for-katakana
      (if (or (not (symbol-bound?
                    'tutcode-rule-exclude-uppercase-for-kigou-in-katakana?))
              (not tutcode-rule-exclude-uppercase-for-kigou-in-katakana?))
        tutcode-rule-uppercase-for-kigou-in-katakana
        ()))))
